;; This file is part of the Emacs mode for FriCAS.  Please read fricas.el
;; instead.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; a list of all FriCAS symbols
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defvar fricas-symbol-list
  (let* ((l (list
"solveLinearlyOverQ"
"particularSolutionOverQ"
"linearDependenceOverZ"
"linearlyDependentOverZ?"
"convert"
"squareFree"
"positiveSolve"
"realSolve"
"univariateSolve"
"triangSolve"
"Y"
"expand"
"unexpand"
"RemainderList"
"*"
"map"
"#"
"coerce"
"maxdeg"
"mindeg"
"reductum"
"coef"
"constant?"
"constant"
"quasiRegular?"
"quasiRegular"
"/"
"degree"
"trunc"
"factor"
"rdivide"
"ldivide"
"left_ext_GCD"
"top_split"
"homo_fact"
"LiePolyIfCan"
"product"
"exp"
"log"
"outputVRML"
"empty?"
"xmlElement"
"xmlAttribute"
"writeVRML"
"writeXml"
"table"
"mindegTerm"
"lquo"
"rquo"
"monomial"
"monomial?"
"mirror"
"sh"
"varList"
"algebraic?"
"transcendent?"
"inGroundField?"
"extensionDegree"
"transcendenceDegree"
"Frobenius"
"Hausdorff"
"minimalRepresentation"
"transformationMatrices"
"findNonZeroEntry"
"minimalMatrix"
"display"
"hankelSystem"
"hankelMatrix"
"hankelIndices"
"medialSet"
"characteristicSet"
"characteristicSerie"
"changeWeightLevel"
"weightedGraph"
"addWArrow!"
"distanceWeighted"
"routeNodeWeight"
"routeArrowWeight"
"cartesian"
"closedTensor"
"closedCartesian"
"weightedDistanceMatrix"
"localIntegralBasis"
"integralBasis"
"weierstrass"
"basis"
"nullSpace"
"columnSpace"
"sumBasis"
"+"
"intBasis"
"rank"
"isBasis?"
"subspace?"
"Zero"
"canonicalBasis"
"complementSpace"
"member?"
"coordinatesIfCan"
"coordinates"
"void"
"tubeRadiusDefault"
"tubePointsDefault"
"var2StepsDefault"
"var1StepsDefault"
"viewWriteAvailable"
"viewWriteDefault"
"viewDefaults"
"viewSizeDefault"
"viewPosDefault"
"pointSizeDefault"
"unitsColorDefault"
"axesColorDefault"
"lineColorDefault"
"pointColorDefault"
"viewThetaDefault"
"viewPhiDefault"
"viewZoomDefault"
"viewDeltaXDefault"
"viewDeltaYDefault"
"viewport3D"
"makeViewport3D"
"subspace"
"modifyPointData"
"options"
"move"
"resize"
"title"
"dimensions"
"viewpoint"
"controlPanel"
"axes"
"diagonals"
"outlineRender"
"drawStyle"
"rotate"
"zoom"
"translate"
"perspective"
"eyeDistance"
"hitherPlane"
"showRegion"
"showClipRegion"
"clipSurface"
"lighting"
"intensity"
"reset"
"colorDef"
"write"
"close"
"key"
"getPickedPoints"
"viewport2D"
"makeViewport2D"
"graphState"
"graphStates"
"graphs"
"putGraph"
"getGraph"
"units"
"points"
"region"
"connect"
"scale"
"show"
"update"
"drawCurves"
"graphCurves"
"hp_solve"
"reduce"
"scan"
"vector"
"zero"
"zero?"
"-"
"dot"
"outerProduct"
"cross"
"length"
"reconstruct"
"remove_denoms"
"rational_reconstruction"
"hensel_update"
"chinese_update"
"empty"
"repack_polys"
"add_slots"
"variable"
"var"
"getName"
"getType"
"toString"
"parseVar"
"parseVarTerm"
"="
"seriesSolve"
"RF2UTS"
"LODO2FUN"
"UTS2UP"
"UP2UTS"
"mpsode"
"ode"
"ode2"
"ode1"
"fixedPointExquo"
"stFuncN"
"stFunc2"
"stFunc1"
"series"
"coefficients"
"quoByVar"
"multiplyCoefficients"
"polynomial"
"^"
"univariatePolynomial"
"differentiate"
"lagrange"
"lambert"
"oddlambert"
"evenlambert"
"generalLambert"
"revert"
"multisect"
"invmultisect"
"integrate"
"concat"
"first"
"elt"
"rest"
"last"
"tail"
"second"
"third"
"cycleEntry"
"cycleLength"
"cycleTail"
"concat!"
"cycleSplit!"
"setfirst!"
"qsetfirst!"
"setelt!"
"setrest!"
"qsetrest!"
"setlast!"
"split!"
"limitPlus"
"dominantTerm"
"puiseux"
"rationalPower"
"laurentRep"
"laurent"
"laurentIfCan"
"multiplyExponents"
"BumInSepFFE"
"squareFreePart"
"terms"
"center"
"order"
"truncate"
"approximate"
"extend"
"eval"
"vectorise"
"unvectorise"
"makeSUP"
"unmakeSUP"
"divideExponents"
"shiftLeft"
"monicDivide"
"karatsubaDivide"
"shiftRight"
"pseudoRemainder"
"discriminant"
"resultant"
"subResultantGcd"
"composite"
"pseudoQuotient"
"pseudoDivide"
"separate"
"karatsuba"
"karatsubaOnce"
"noKaratsuba"
"divideIfCan"
"completeDecompose"
"decomposeIfCan"
"monicCompleteDecompose"
"monicDecomposeIfCan"
"leftFactorIfCan"
"rightFactorIfCan"
"monicRightFactorIfCan"
"splitDenominator"
"clearDenominator"
"commonDenominator"
"SEGMENT"
"segment"
"hasHi"
"taylorRep"
"removeZeroes"
"taylor"
"taylorIfCan"
"rationalFunction"
"pre_lr"
"pre_smith"
"pre_gauss"
"hadamard"
"irreducible?"
"su_irreducible?"
"sufactor_square_free"
"sufactor"
"factorSquareFree"
"prime?"
"resetVariableOrder"
"getVariableOrder"
"setVariableOrder"
"more?"
"largest"
"userOrdered?"
"less?"
"getOrder"
"setOrder"
"undirectedGraph"
"diagramSvg2"
"qconvert"
"doFactor"
"tryTwoFactor"
"generalTwoFactor"
"select"
"loopPoints"
"cosSinInfo"
"unitVector"
"point"
"tube"
"setClosed"
"open?"
"closed?"
"listLoops"
"getCurve"
"infRittWu?"
"basicSet"
"initials"
"quasiComponent"
"normalized?"
"reduced?"
"stronglyReduced?"
"headReduced?"
"initiallyReduced?"
"autoReduced?"
"rewriteSetWithReduction"
"stronglyReduce"
"headReduce"
"initiallyReduce"
"removeZero"
"collectQuasiMonic"
"reduceByQuasiMonic"
"zeroSetSplit"
"zeroSetSplitIntoTriangularSystems"
"algebraicVariables"
"extendIfCan"
"coHeight"
"apply_taylor"
"applyTaylor"
"taylor_via_lode"
"taylor_via_deriv"
"coefficient"
"fintegrate"
"expandTrigProducts"
"removeSinhSq"
"removeCoshSq"
"removeSinSq"
"removeCosSq"
"coth2tanh"
"cot2tan"
"tanh2coth"
"tan2cot"
"tanh2trigh"
"tan2trig"
"sinh2csch"
"sin2csc"
"sech2cosh"
"sec2cos"
"csch2sinh"
"csc2sin"
"coth2trigh"
"cot2trig"
"cosh2sech"
"cos2sec"
"expandLog"
"expandPower"
"simplifyLog"
"simplifyExp"
"htrigs"
"simplify"
"LowTriBddDenomInv"
"UpTriBddDenomInv"
"trigs2explogs"
"complexForm"
"real?"
"imag"
"real"
"trigs"
"complexElementary"
"complexNormalize"
"tan"
"sin"
"sec"
"csc"
"cot"
"cos"
"tree"
"pi"
"createThreeSpace"
"direction"
"nonQsign"
"sign"
"coerceL"
"eval_with_timeout"
"get_text"
"text?"
"text"
"get_math"
"display_math?"
"display_math"
"text_math?"
"text_math"
"get_call"
"m_call?"
"m_call"
"ungroup"
"group?"
"group"
"writeLine!"
"readLine!"
"readLineIfCan!"
"readIfCan!"
"endOfFile?"
"get_token!"
"at_eos?"
"parse"
"epilogue"
"tex"
"new"
"prologue"
"getDialect"
"setDialect"
"setEpilogue!"
"setTex!"
"setPrologue!"
"xftestLibraryError"
"testLibraryError"
"xftestTrue"
"testTrue"
"xftestNotEquals"
"testNotEquals"
"xftestComplexEquals"
"testComplexEquals"
"xftestRealEquals"
"testRealEquals"
"xftestEquals"
"testEquals"
"addWarning"
"incXfFatal"
"incFatal"
"incXfLibraryError"
"incLibraryError"
"incXfFail"
"incXfPass"
"incFail"
"incPass"
"incTest"
"statistics"
"testcaseNoClear"
"testcase"
"testsuiteNoClear"
"testsuite"
"testRelativePrecision"
"testAbsolutePrecision"
"xftestComplexEqualsAux"
"testComplexEqualsAux"
"xftestRealEqualsAux"
"testRealEqualsAux"
"testEqualsAuxCmp"
"xftestLibraryErrorAux"
"testLibraryErrorAux"
"xftestTrueAux"
"testTrueAux"
"xftestNotEqualsAux"
"testNotEqualsAux"
"xftestEqualsAux"
"testEqualsAux"
"tensor"
"linearExtend"
"stripCommentsAndBlanks"
"interpretString"
"insert!"
"extractIfCan"
"makingStats?"
"printingInfo?"
"usingTable?"
"clearTable!"
"printStats!"
"startStats!"
"printInfo!"
"initTable!"
"tanNa"
"tanAn"
"tanSum"
"tableau"
"listOfLists"
"mr"
"maxrow"
"inverse"
"slex"
"lex"
"tab"
"tab1"
"bat"
"bat1"
"untab"
"bumptab1"
"bumptab"
"bumprow"
"triangularSystems"
"solve"
"declare!"
"fortranTypeOf"
"parametersOf"
"typeList"
"externalList"
"typeLists"
"newTypeLists"
"printTypes"
"symbolTable"
"showTheSymbolTable"
"clearTheSymbolTable"
"newSubProgram"
"currentSubProgram"
"endSubProgram"
"argumentList!"
"returnType!"
"printHeader"
"returnTypeOf"
"argumentListOf"
"symbolTableOf"
"symFunc"
"resetNew"
"name"
"scripted?"
"scripts"
"script"
"subscript"
"superscript"
"argscript"
"string"
"sample"
"detSysNS"
"ncDetSys"
"detSys"
"linearize"
"transform"
"ansatz"
"LT"
"GT"
"LE"
"GE"
"OR"
"EQ"
"AND"
"NOT"
"outputForm"
"sum"
"construct"
"lhs"
"rhs"
"leaf?"
"root?"
"internal?"
"birth"
"child"
"children"
"numberOfChildren"
"shallowCopy"
"deepCopy"
"merge"
"addPoint"
"addPoint2"
"addPointLast"
"modifyPoint"
"closeComponent"
"defineProperty"
"traverse"
"extractPoint"
"extractIndex"
"extractClosed"
"extractProperty"
"level"
"parent"
"pointData"
"primitivePart"
"subresultantVector"
"acsch"
"asech"
"acoth"
"atanh"
"acosh"
"asinh"
"csch"
"sech"
"coth"
"tanh"
"cosh"
"sinh"
"acsc"
"asec"
"acot"
"atan"
"acos"
"asin"
"sinhcosh"
"sincos"
"lazyIntegrate"
"addiag"
"gderiv"
"deriv"
"mapmult"
"int"
"oddintegers"
"integers"
"monom"
"compose"
"exquo"
"recip"
"prodiag"
"general_Lambert_product"
"nlde"
"powern"
"mapdiv"
"lazyGintegrate"
"power"
"ucodeToString"
"uentries"
"repeating"
"repeating?"
"findCycle"
"delay"
"cons"
"showElements"
"showAllElements"
"showAll?"
"stream"
"filterWhile"
"filterUntil"
"distributionBySTransform"
"STransform"
"STransform2"
"STransform1"
"compound"
"xform"
"identity"
"stranslate"
"stransform"
"tensorMap"
"log1"
"exp0"
"init"
"nextItem"
"explicitlyFinite?"
"possiblyInfinite?"
"stack"
"leadingCoefficient"
"leadingMonomial"
"internalAugment"
"internalZeroSetSplit"
"pre_process"
"printInfo"
"upDateBranches"
"decompose"
"internalDecompose"
"transcendentalDecompose"
"algebraicDecompose"
"numberOfVariables"
"KrullNumber"
"lowerCase"
"lowerCase!"
"upperCase"
"upperCase!"
"prefix?"
"suffix?"
"substring?"
"match?"
"replace"
"position"
"split"
"trim"
"leftTrim"
"rightTrim"
"join"
"transpose"
"squareMatrix"
"spnt"
"sipnt"
"svec"
"sivec"
"min"
"max"
"dimension"
"Pnan?"
"distanceSquared"
"distance"
"parallel"
"colinearity"
"perpendicular"
"toPoint"
"toVector"
"isPoint?"
"isVector?"
"inBounds?"
"screenCoordX"
"screenCoordY"
"screenCoordZ"
"screenCoords"
"extendedCoords"
"extractSplittingLeaf"
"updateStatus!"
"conditions"
"result"
"nodeOf?"
"subNodeOf?"
"remove"
"remove!"
"splitNodeOf!"
"value"
"condition"
"status"
"copy"
"setValue!"
"setCondition!"
"setStatus!"
"setEmpty!"
"infLex?"
"subNode?"
"weierstrassSigma0"
"weierstrassZeta0"
"weierstrassPPrime0"
"weierstrassP0"
"lambertW0"
"meijerG"
"hypergeometricF"
"wilsonW"
"racahR"
"meixnerP"
"meixnerM"
"laguerreL"
"krawtchoukK"
"jacobiP"
"hermiteH"
"hahnS"
"hahnR"
"hahnQ"
"hahn_p"
"charlierC"
"riemannZeta"
"lerchPhi"
"jacobiTheta"
"jacobiZeta"
"jacobiDn"
"jacobiCn"
"jacobiSn"
"ellipticPi"
"ellipticF"
"ellipticE"
"ellipticK"
"kelvinKer"
"kelvinKei"
"kelvinBer"
"kelvinBei"
"legendreQ"
"legendreP"
"kummerU"
"kummerM"
"lommelS2"
"lommelS1"
"hankelH2"
"hankelH1"
"struveL"
"struveH"
"weberE"
"angerJ"
"whittakerW"
"whittakerM"
"weierstrassPInverse"
"weierstrassZeta"
"weierstrassSigma"
"weierstrassPPrime"
"weierstrassP"
"polylog"
"lambertW"
"airyBiPrime"
"airyBi"
"airyAiPrime"
"airyAi"
"besselK"
"besselI"
"besselY"
"besselJ"
"Gamma"
"polygamma"
"digamma"
"Beta"
"conjugate"
"diracDelta"
"fractionPart"
"floor"
"ceiling"
"unitStep"
"abs"
"outputAsTex"
"outputAsMathML"
"outputAsFortran"
"create3Space"
"numberOfComponents"
"numberOfComposites"
"components"
"composites"
"enterPointData"
"point?"
"curve"
"curve?"
"closedCurve"
"closedCurve?"
"polygon"
"polygon?"
"mesh"
"mesh?"
"lp"
"lllip"
"lllp"
"llprop"
"lprop"
"objects"
"check"
"insertionSort!"
"bubbleSort!"
"omega"
"omegapower"
"ordinalAdd"
"ordinalMul"
"ordinalPower"
"integerPart"
"limitPart"
"decomposeFunc"
"radical_solve"
"cyclotomic_case?"
"contractSolve"
"radicalRoots"
"radicalSolve"
"aQuartic"
"aCubic"
"aQuadratic"
"aLinear"
"quartic"
"cubic"
"quadratic"
"linear"
"particularSolution"
"csubst"
"remap_variables"
"diophantineSystem"
"completeSmith"
"smith"
"completeHermite"
"hermite"
"scalarMatrix"
"diagonalMatrix"
"diagonal"
"trace"
"diagonalProduct"
"determinant"
"minordet"
"Pfaffian"
"D"
"Delta"
"ski"
"I"
"K"
"S"
"parseSki"
"parseTerm"
"getChildren"
"atom?"
"variable?"
"isI?"
"isK?"
"isS?"
"getVariable"
"freeVariable?"
"redux"
"push!"
"pop!"
"top"
"~"
"\\/"
"/\\"
"not"
"xor"
"Not"
"And"
"Or"
"dunceHat"
"kleinBottle"
"projectiveSpace"
"moebiusBand"
"band"
"torusSurface"
"line"
"sphereSurface"
"sphereSolid"
"simplicialComplex"
"simplicialComplexIfCan"
"addSimplex"
"maxIndex"
"minIndex"
"grade"
"sort"
"addImpliedFaces"
"boundary"
"star"
"link"
"cone"
"refactorIndexes"
"makeDisjoint"
"simplicialJoin"
"oneSkeleton"
"fundamentalGroup"
"chain"
"coChain"
"homology"
"coHomology"
"countRealRootsMultiple"
"SturmHabichtMultiple"
"countRealRoots"
"SturmHabicht"
"SturmHabichtCoefficients"
"SturmHabichtSequence"
"unrankImproperPartitions1"
"unrankImproperPartitions0"
"subSet"
"numberOfImproperPartitions"
"nextPartition"
"nextLatticePermutation"
"nextColeman"
"makeYoungTableau"
"listYoungTableaus"
"inverseColeman"
"coleman"
"stoseSquareFreePart"
"stoseInvertibleSet"
"stoseInvertible?"
"stoseInvertibleSet_reg"
"stoseInvertible?_reg"
"stoseInvertibleSet_sqfreg"
"stoseInvertible?_sqfreg"
"stoseLastSubResultant"
"stoseIntegralLastSubResultant"
"stoseInternalLastSubResultant"
"stosePrepareSubResAlgo"
"stopTableInvSet!"
"startTableInvSet!"
"stopTableGcd!"
"startTableGcd!"
"branchIfCan"
"prepareDecompose"
"removeSuperfluousCases"
"subCase?"
"removeSuperfluousQuasiComponents"
"subQuasiComponent?"
"internalSubQuasiComponent?"
"internalInfRittWu?"
"internalSubPolSet?"
"subPolSet?"
"subTriSet?"
"moreAlgebraic?"
"algebraicSort"
"supDimElseRittWu?"
"stopTable!"
"startTable!"
"fortran"
"eq"
"null?"
"pair?"
"list?"
"string?"
"symbol?"
"integer?"
"float?"
"destruct"
"symbol"
"integer"
"float"
"car"
"cdr"
"incrementKthElement"
"replaceKthElement"
"elements"
"setOfMinN"
"enumerate"
"delta"
"subsetLattice"
"complement"
"latex"
"set"
"intersect"
"difference"
"symmetricDifference"
"subset?"
"union"
"apply"
"sequence"
"firstn"
"dilate"
"ncols"
"nrows"
"allIndices"
"elimZeroCols!"
"purge!"
"sortedPurge!"
"row"
"setRow!"
"deleteRow!"
"consRow!"
"appendRow!"
"extract"
"rowEchelon"
"setGcdMode"
"primitiveRowEchelon"
"pivot"
"pivots"
"horizJoin"
"horizSplit"
"BY"
"low"
"high"
"incr"
"reverse"
"equation"
"structuralConstants"
"normalisePoint"
"namedPoints"
"namedBranch"
"isPointLeaf?"
"isNodeLeaf?"
"isNodeBranch?"
"getNames"
"findPoint"
"addPoints!"
"addNode!"
"findNode"
"pointList"
"indexes"
"curveLoops"
"stube"
"sierpinskiDivide"
"subdivide"
"singleFace"
"smesh"
"writeObj"
"writeX3d"
"writeSvgQuantised"
"writeSvg"
"toObj"
"toX3D"
"toSVG"
"setTransform!"
"removeChild!"
"addChild!"
"addArrows2Din2D"
"createArrows2Din2D"
"addPlot2Din3Dparametric"
"createPlot2Din3Dparametric"
"addPlot2Din3D"
"createPlot2Din3D"
"addPlot1Din3Dparametric"
"createPlot1Din3Dparametric"
"addPlot1Din2Dparametric"
"createPlot1Din2Dparametric"
"addPlot1Din2D"
"createPlot1Din2D"
"addSceneTransform"
"createSceneTransform"
"addSceneMaterial"
"createSceneMaterial"
"addSceneGraph"
"createSceneGraph"
"addSceneRuler"
"createSceneRuler"
"addScenePattern"
"createScenePattern"
"addSceneGrid"
"createSceneGrid"
"addSceneClip"
"createSceneClip"
"addSceneText"
"createSceneText"
"addSceneBox"
"createSceneBox"
"addSceneIFS"
"createSceneIFS"
"addSceneNamedPoints"
"createSceneNamedPoints"
"addSceneArrow"
"createSceneArrow"
"addSceneArrows"
"createSceneArrows"
"addSceneUse"
"createSceneUse"
"addSceneDef"
"createSceneDef"
"addSceneShape"
"createSceneShape"
"addSceneLines"
"createSceneLines"
"addSceneLine"
"createSceneLine"
"addSceneGroup"
"createSceneGroup"
"createSceneRoot"
"allSimpleCells"
"hasDimension?"
"samplePoint"
"variableOf"
"parse_integer"
"binarySearch"
"enterInCache"
"linearSearch"
"clearCache"
"getCentre"
"getMax"
"getMin"
"isBox?"
"isEllipse?"
"isNull?"
"lineIntersect"
"containsPoint?"
"extendToPoint"
"sunion"
"intersection"
"ellipseBoundary"
"boxBoundary"
"nullBoundary"
"create"
"rur"
"ruleset"
"rules"
"rule"
"suchThat"
"pattern"
"quotedOperators"
"rsimp1"
"rsimp"
"toseSquareFreePart"
"toseInvertibleSet"
"toseInvertible?"
"toseLastSubResultant"
"integralLastSubResultant"
"internalLastSubResultant"
"prepareSubResAlgo"
"purelyAlgebraic?"
"purelyTranscendental?"
"algebraicCoefficients?"
"purelyAlgebraicLeadingMonomial?"
"invertibleElseSplit?"
"invertible?"
"invertibleSet"
"lastSubResultantElseSplit"
"lastSubResultant"
"augment"
"negative?"
"positive?"
"definingPolynomial"
"allRootsOf"
"rootOf"
"relativeApprox"
"mvar"
"mdeg"
"head"
"deepestTail"
"iteratedInitials"
"deepestInitial"
"monic?"
"quasiMonic?"
"mainMonomial"
"leastMonomial"
"mainCoefficients"
"mainMonomials"
"RittWuCompare"
"supRittWu?"
"prem"
"pquo"
"lazyPrem"
"lazyPquo"
"lazyPremWithDefault"
"lazyPseudoDivide"
"monicModulo"
"lazyResidueClass"
"retractIfCan"
"retract"
"primPartElseUnitCanonical"
"primPartElseUnitCanonical!"
"exactQuotient"
"exactQuotient!"
"extendedSubResultantGcd"
"halfExtendedSubResultantGcd1"
"halfExtendedSubResultantGcd2"
"subResultantChain"
"LazardQuotient"
"LazardQuotient2"
"next_subResultant2"
"iexactQuo"
"gcd"
"primitivePart!"
"mainContent"
"mainPrimitivePart"
"mainSquareFreePart"
"my_root3"
"my_sqrt"
"quartic2"
"complex_roots"
"roman"
"left"
"right"
"size"
"middle"
"refine"
"mightHaveRoots"
"norm"
"wholePart"
"round"
"characteristic"
"try_real"
"annihilate?"
"rectangularMatrix"
"matrix"
"minRowIndex"
"maxRowIndex"
"minColIndex"
"maxColIndex"
"qelt"
"column"
"interpolate"
"ridHack1"
"geometric"
"poisson"
"binomial"
"uniform"
"alg_split_root0"
"alg_split_roots"
"t"
"F"
"chiSquare"
"exponential"
"normal"
"chiSquare1"
"exponential1"
"normal01"
"uniform01"
"multivariate"
"univariate"
"mainVariable"
"variables"
"solveRetract"
"showScalarValues"
"showArrayValues"
"lift"
"expt"
"double"
"scanOneDimSubspaces"
"meatAxe"
"isAbsolutelyIrreducible?"
"areEquivalent?"
"standardBasisOfCyclicSubmodule"
"cyclicSubmodule"
"createRandomElement"
"completeEchelonBasis"
"permutationRepresentation"
"tensorProduct"
"symmetricTensors"
"createGenericMatrix"
"antisymmetricTensors"
"orthonormalBasis"
"gramschmidt"
"normalise"
"eigenMatrix"
"radicalEigenvalues"
"radicalEigenvector"
"radicalEigenvectors"
"ref"
"deref"
"setref"
"ReduceOrder"
"eltable?"
"values"
"getEq"
"makeFEq"
"makeRec"
"algebraicOf"
"mainCharacterization"
"realZeros"
"midpoints"
"midpoint"
"rdHack1"
"weighted"
"exp_lower_bound"
"param_rde2"
"param_rde"
"do_param_RDE"
"do_risch_DE"
"risch_de_ext"
"mk_erf"
"ei_int"
"SPDE1"
"multi_SPDE"
"sqrt"
"mainForm"
"mainDefiningPolynomial"
"mainValue"
"rename!"
"rename"
"nodes"
"cyclic?"
"leaves"
"child?"
"node?"
"setchildren!"
"setvalue!"
"rationalIfCan"
"rational?"
"rational"
"seed"
"reseed"
"randnum"
"radix"
"wholeRagits"
"fractRagits"
"prefixRagits"
"cycleRagits"
"wholeRadix"
"fractRadix"
"nthRoot"
"queue"
"imagI"
"imagJ"
"imagK"
"quatern"
"enqueue!"
"dequeue!"
"rotate!"
"front"
"back"
"quadraticForm"
"numer"
"denom"
"numerator"
"denominator"
"radicalSimplify"
"quasiAlgebraicSet"
"setStatus"
"definingEquations"
"definingInequation"
"idealSimplify"
"reducedDiscriminant"
"pushup"
"pushdown"
"acschIfCan"
"asechIfCan"
"acothIfCan"
"atanhIfCan"
"acoshIfCan"
"asinhIfCan"
"cschIfCan"
"sechIfCan"
"cothIfCan"
"tanhIfCan"
"coshIfCan"
"sinhIfCan"
"acscIfCan"
"asecIfCan"
"acotIfCan"
"atanIfCan"
"acosIfCan"
"asinIfCan"
"cscIfCan"
"secIfCan"
"cotIfCan"
"tanIfCan"
"cosIfCan"
"sinIfCan"
"logIfCan"
"expIfCan"
"nthRootIfCan"
"shade"
"hue"
"color"
"phiCoord"
"thetaCoord"
"rCoord"
"zCoord"
"yCoord"
"xCoord"
"companionBlocks"
"changeBase"
"normalForm"
"removeIrreducibleRedundantFactors"
"lazyIrreducibleFactors"
"irreducibleFactors"
"removeRedundantFactorsInPols"
"removeRedundantFactorsInContents"
"removeRoughlyRedundantFactorsInContents"
"univariatePolynomialsGcds"
"squareFreeFactors"
"rewriteIdealWithQuasiMonicGenerators"
"rewriteSetByReducingWithParticularGenerators"
"crushedSet"
"roughBasicSet"
"interReduce"
"removeRoughlyRedundantFactorsInPol"
"removeRoughlyRedundantFactorsInPols"
"bivariatePolynomials"
"bivariate?"
"linearPolynomials"
"linear?"
"univariatePolynomials"
"univariate?"
"quasiMonicPolynomials"
"selectAndPolynomials"
"selectOrPolynomials"
"selectPolynomials"
"probablyZeroDim?"
"possiblyNewVariety?"
"certainlySubVariety?"
"removeRedundantFactors"
"unprotectedRemoveRedundantFactors"
"removeSquaresIfCan"
"mainVariables"
"mainVariable?"
"collectUnder"
"collect"
"collectUpper"
"trivialIdeal?"
"roughBase?"
"roughSubIdeal?"
"roughEqualIdeals?"
"roughUnitIdeal?"
"headRemainder"
"remainder"
"rewriteIdealWithHeadRemainder"
"rewriteIdealWithRemainder"
"triangular?"
"listBranches"
"xRange"
"yRange"
"zRange"
"pole?"
"complete"
"partition"
"powers"
"pdct"
"next_sousResultant2"
"divide"
"semiResultantReduitEuclidean"
"resultantReduitEuclidean"
"resultantReduit"
"schema"
"chainSubResultants"
"semiDiscriminantEuclidean"
"discriminantEuclidean"
"semiSubResultantGcdEuclidean1"
"semiSubResultantGcdEuclidean2"
"subResultantGcdEuclidean"
"semiLastSubResultantEuclidean"
"lastSubResultantEuclidean"
"semiDegreeSubResultantEuclidean"
"degreeSubResultantEuclidean"
"degreeSubResultant"
"semiIndiceSubResultantEuclidean"
"indiceSubResultantEuclidean"
"indiceSubResultant"
"semiResultantEuclidean1"
"semiResultantEuclidean2"
"resultantEuclidean"
"integerBound"
"get_rational_roots"
"merge!"
"print"
"primes"
"prevPrime"
"nextPrime"
"primitiveElement"
"integral"
"alg_exquo"
"alg_trial_division"
"alg_reduce"
"alg_reduce0"
"coeffs1"
"coeffs0"
"lcz"
"lcx0"
"le"
"firstUncouplingMatrix"
"posetL7"
"posetP6"
"posetO6"
"posetM5"
"posetN5"
"completelyOrderedSet"
"powerset"
"finitePoset"
"getVert"
"getArr"
"addObject"
"addArrow"
"opposite"
"implies"
"meetIfCan"
"joinIfCan"
"glb"
"lub"
"upperSet"
"lowerSet"
"indexToObject"
"objectToIndex"
"isChain?"
"isAntiChain?"
"moebius"
"zetaMatrix"
"coverMatrix"
"isDirected?"
"createWidth"
"createX"
"createY"
"<="
">="
">"
"<"
"extended_gcd"
"lcm"
"pa_to_sup"
"to_mod_pa"
"vector_combination"
"remainder!"
"divide!"
"pow"
"truncated_mul_add2"
"truncated_mul_add"
"truncated_multiplication"
"mul"
"mul_by_scalar"
"mul_by_binomial"
"vector_add_mul"
"eval_at"
"copy_slice"
"copy_first"
"nthr"
"froot"
"qroot"
"rroot"
"isPower"
"isExpt"
"isTimes"
"isPlus"
"minimumDegree"
"content"
"lazyVariations"
"sturmVariationsOf"
"boundOfCauchy"
"sturmSequence"
"sylvesterSequence"
"pToDmp"
"dmpToP"
"hdmpToP"
"pToHdmp"
"hdmpToDmp"
"dmpToHdmp"
"legendre"
"laguerre"
"fixedDivisor"
"euler"
"cyclotomic"
"chebyshevU"
"chebyshevT"
"bernoulli"
"patternMatchTimes"
"patternMatch"
"fixPredicate"
"multiple"
"optional"
"calcRanges"
"pointPlot"
"plot"
"tRange"
"tValues"
"minPoints3D"
"setMinPoints3D"
"maxPoints3D"
"setMaxPoints3D"
"screenResolution3D"
"setScreenResolution3D"
"adaptive3D?"
"setAdaptive3D"
"numFunEvals3D"
"debug3D"
"plotPolar"
"parametric?"
"minPoints"
"setMinPoints"
"maxPoints"
"setMaxPoints"
"screenResolution"
"setScreenResolution"
"adaptive?"
"setAdaptive"
"numFunEvals"
"debug"
"inconsistent?"
"sqfree"
"regime"
"redmat"
"ParCond"
"overset?"
"nextSublist"
"minset"
"minrank"
"maxrank"
"factorset"
"B1solve"
"redpps"
"ParCondList"
"hasoln"
"pr2dmp"
"se2rfi"
"dmp2rfi"
"bsolve"
"rdregime"
"wrregime"
"psolve"
"LagrangeInterpolation"
"principalIdeal"
"expressIdealMember"
"qcoerce"
"totalGroebner"
"lexGroebner"
"youngGroup"
"rubiksGroup"
"janko2"
"mathieu24"
"mathieu23"
"mathieu22"
"mathieu12"
"mathieu11"
"dihedralGroup"
"cyclicGroup"
"abelianGroup"
"alternatingGroup"
"symmetricGroup"
"gcdPrimitive"
"partialFraction"
"compactFraction"
"numberOfFractionalTerms"
"fractionalTerms"
"padicallyExpand"
"padicFraction"
"group_terms"
"polyred"
"doubleDisc"
"mix"
"badNum"
"getGoodPrime"
"torsionIfCan"
"torsion?"
"simplifyCoeffs"
"handle_imaginary"
"possibleOrder"
"cmult"
"gcdPolynomial"
"squareFreePolynomial"
"factorPolynomial"
"factorSquareFreePolynomial"
"solveLinearPolynomialEquation"
"conditionP"
"charthRoot"
"bivariateSLPEBR"
"randomR"
"factorSquareFreeByRecursion"
"factorByRecursion"
"solveLinearPolynomialEquationByRecursion"
"productFacet"
"getIndexs"
"getMaxLeft"
"getMaxRight"
"setMult!"
"addVertex2"
"modpeval"
"modpreduction"
"eval1"
"eval1a"
"generators"
"random"
"base"
"strongGenerators"
"wordsForStrongGenerators"
"permutationGroup"
"orbit"
"orbits"
"wordInStrongGenerators"
"wordInGenerators"
"movedPoints"
"initializeGroupForWordProblem"
"relationsInStrongGenerators"
"relationsInGenerators"
"perm_to_vec"
"cycle"
"cycles"
"permanent"
"listRepresentation"
"coercePreimagesImages"
"coerceListOfPairs"
"cyclePartition"
"numberOfCycles"
"even?"
"odd?"
"fixedPoints"
"coerceImages"
"ptree"
"diff_map"
"id_map"
"adjoint"
"One"
"listOfTerms"
"retractable?"
"badValues"
"addBadValue"
"satisfy?"
"predicate"
"isOp"
"isQuotient"
"isList"
"depth"
"inR?"
"quoted?"
"generic?"
"multiple?"
"optional?"
"hasPredicate?"
"predicates"
"setPredicates"
"withPredicates"
"patternVariable"
"setTopPredicate"
"topPredicate"
"hasTopPredicate?"
"resetBadValues"
"getBadValues"
"optpair"
"failed?"
"failed"
"getMatch"
"addMatch"
"insertMatch"
"addMatchRestricted"
"Is"
"is?"
"makeResult"
"atoms"
"lists"
"permutations"
"sequences"
"shufflein"
"shuffle"
"conjugates"
"distinct_partitions"
"odd_partitions"
"partitions"
"coordinate"
"surface"
"bottom"
"jacobiPathArray"
"motzkinPathArray"
"get_value"
"complex_curve"
"dark"
"dim"
"bright"
"pastel"
"light"
"continuedFraction"
"digits"
"modulus"
"moduloP"
"quotientByP"
"root"
"pade"
"pade_cf2"
"pade_cf"
"pade_stream2"
"pade_stream"
"padecf"
"message"
"messagePrint"
"hspace"
"vspace"
"rspace"
"hconcat"
"vconcat"
"prefix"
"infix"
"postfix"
"infix?"
"label"
"box"
"zag"
"over"
"slash"
"assign"
"rarrow"
"sub"
"super"
"presub"
"presuper"
"supersub"
"quote"
"prime"
"overbar"
"overlabel"
"prod"
"brace"
"bracket"
"paren"
"pile"
"commaSeparate"
"semicolonSeparate"
"blankSeparate"
"~="
"rem"
"quo"
"and"
"or"
"height"
"width"
"lines"
"pad"
"hcenter"
"outputList"
"output"
"rightDivide"
"leftDivide"
"monicRightDivide"
"monicLeftDivide"
"times"
"leftQuotient"
"leftRemainder"
"leftExactQuotient"
"leftGcd"
"leftExtendedGcd"
"rightLcm"
"rightQuotient"
"rightRemainder"
"rightExactQuotient"
"rightGcd"
"rightExtendedGcd"
"right_ext_ext_GCD"
"leftLcm"
"reverseLex"
"totalLex"
"pureLex"
"plusInfinity"
"minusInfinity"
"finite?"
"infinite?"
"whatInfinity"
"getDatabase"
"removeHandler!"
"setHandler!"
"handler"
"knownHandler?"
"conjug"
"evaluate"
"evaluateInverse"
"opeval"
"makeop"
"infinity"
"OMserve"
"OMsend"
"OMreceive"
"OMunhandledSymbol"
"OMsupportsSymbol?"
"OMsupportsCD?"
"OMlistSymbols"
"OMlistCDs"
"OMreadStr"
"OMreadFile"
"OMread"
"OMwrite"
"OMParseError?"
"OMUnknownCD?"
"OMUnknownSymbol?"
"OMReadError?"
"errorKind"
"errorInfo"
"omError"
"OMencodingUnknown"
"OMencodingXML"
"OMencodingSGML"
"OMencodingBinary"
"OMgetType"
"OMgetSymbol"
"OMgetString"
"OMgetVariable"
"OMgetFloat"
"OMgetInteger"
"OMgetEndObject"
"OMgetEndError"
"OMgetEndBVar"
"OMgetEndBind"
"OMgetEndAttr"
"OMgetEndAtp"
"OMgetEndApp"
"OMgetObject"
"OMgetError"
"OMgetBVar"
"OMgetBind"
"OMgetAttr"
"OMgetAtp"
"OMgetApp"
"OMputSymbol"
"OMputString"
"OMputVariable"
"OMputFloat"
"OMputInteger"
"OMputEndObject"
"OMputEndError"
"OMputEndBVar"
"OMputEndBind"
"OMputEndAttr"
"OMputEndAtp"
"OMputEndApp"
"OMputObject"
"OMputError"
"OMputBVar"
"OMputBind"
"OMputAttr"
"OMputAtp"
"OMputApp"
"OMsetEncoding"
"OMclose"
"OMopenString"
"OMopenFile"
"OMbindTCP"
"OMconnectTCP"
"OMconnOutDevice"
"OMconnInDevice"
"OMcloseConn"
"OMmakeConn"
"precondition"
"is_symbol?"
"has_op?"
"arguments"
"operator"
"atom_to_string"
"orientedFacet"
"orientedFacetUnsigned"
"orientedFacetSigned"
"orientedFacetIfCan"
"getIndexes"
"getIndexesSigned"
"allSubsets"
"isSubsetOf?"
"sameFace?"
"subtract"
"reindex"
"boolWordPermute"
"addVertex"
"variationOfParameters"
"wronskianMatrix"
"solveInField"
"triangulate"
"ricDsolve"
"polyRicDE"
"singRicDE"
"reduceLODE"
"integrate_sols"
"indicialEquationAtInfinity"
"ratDsolve"
"changeVar"
"constantCoefficientRicDE"
"leadingCoefficientRicDE"
"denomRicDE"
"indicialEquation"
"indicialEquations"
"denomLODE"
"algDsolve"
"diff"
"expint"
"constDsolve"
"octon"
"imagi"
"imagj"
"imagk"
"imagE"
"inv"
"sup"
"inf"
"trapezoidalo"
"simpsono"
"rombergo"
"trapezoidal"
"simpson"
"romberg"
"atrapezoidal"
"asimpson"
"aromberg"
"rk4f"
"rk4qc"
"rk4a"
"rk4"
"FormatRadix"
"ScanFloatIgnoreSpacesIfCan"
"ScanFloatIgnoreSpaces"
"ScanRoman"
"FormatRoman"
"ScanArabic"
"FormatArabic"
"complexNumericIfCan"
"numericIfCan"
"complexNumeric"
"numeric"
"eulerE"
"bernoulliB"
"lazyPseudoRemainder"
"lazyPseudoQuotient"
"subResultantsChain"
"extendedResultant"
"halfExtendedResultant1"
"halfExtendedResultant2"
"realEigenvectors"
"realEigenvalues"
"characteristicPolynomial"
"npcoef"
"normFactors"
"normInvertible?"
"outputArgs"
"normalize"
"normalizedAssociate"
"shift"
"sPol"
"virtualDegree"
"hMonic"
"redPol"
"groebner"
"newton"
"complexEigenvectors"
"complexEigenvalues"
"reduceBasis"
"reduceBasis0"
"naiveBeckermannLabahn0"
"naiveBeckermannLabahn1"
"naiveBeckermannLabahnMultipoint"
"naiveBeckermannLabahn"
"antiCommutator"
"associator"
"commutator"
"plenaryPower"
"normDeriv2"
"myDegree"
"coefChoose"
"intChoose"
"nsqfree"
"consnewpol"
"univcase"
"compdegd"
"logDependenceQ"
"mergeDifference"
"systemCommand"
"multiset"
"mrv_rewrite0"
"mrv_rewrite"
"expr_to_series"
"mrv_set"
"mrv_cmp"
"mrv_sign"
"mrv_limit1"
"mrv_limit"
"mrv_normalize"
"pushuconst"
"pushucoef"
"pushdterm"
"totalfract"
"normalDenom"
"splitSquarefree"
"generator"
"derivationCoordinates"
"moment2monotoneCumulant"
"moment2Stransform"
"jacobi2poly"
"hankelDeterminant"
"monotoneCumulant2momentPoly"
"monotoneCumulant2moment"
"moment2booleanCumulant"
"booleanCumulant2moment"
"moment2freeCumulant"
"freeCumulant2moment"
"moment2jacobi2"
"moment2jacobi"
"moment2nthJacobi"
"moment2cumulant"
"cumulant2moment"
"exQuo"
"exponent"
"index"
"setPoly"
"Vectorise"
"UnVectorise"
"frobenius"
"VSUPS_to_VPA"
"LLF_to_LPA"
"gen_Monte_Carlo_check"
"HP_solve"
"unpack_poly"
"get_variables"
"LLFPI_to_LPA"
"LLFI_to_LPA"
"VSUPPI_to_VPA"
"VSUPI_to_VPA"
"check_sol1a"
"HP_solve_M"
"HP_solve_PA"
"HP_solve_P"
"HP_solve_A"
"HP_solve_I"
"ddfact"
"mfactor"
"coerceS"
"lifting"
"corrPoly"
"compiledFunction"
"unaryFunction"
"makeRecord"
"function"
"make_imaginary_part_function"
"make_real_part_function"
"makeFloatFunction"
"binaryFunction"
"maxint"
"normalizedDivide"
"rowEchelonLocal"
"rowEchLocal"
"rowEch"
"modular_compose"
"power_matrix"
"copy_mat_part"
"shift_mat!"
"split_mat!"
"trim_mat!"
"empty_mat?"
"empty_mat"
"empty_poly"
"random_poly"
"sub_poly"
"add_poly"
"sub1!"
"copy_poly"
"monomial1"
"mod_exp"
"red_pol!"
"get_extension_degree"
"get_char"
"get_mod"
"ini_rdata"
"mantissa"
"precision"
"maximumExponent"
"minimumExponent"
"multifunctionGraph"
"coAdjoint"
"contraAdjoint"
"limit"
"toCayleyGraph"
"toPermutation"
"trial_division"
"subst_vars"
"ldegree"
"ptFunc"
"meshPar1Var"
"meshFun2Var"
"meshPar2Var"
"removeDuplicates!"
"duplicates"
"bandedJacobian"
"jacobian"
"bandedHessian"
"hessian"
"laplacian"
"divergence"
"gradient"
"power!"
"times!"
"rightScalarTimes!"
"leftScalarTimes!"
"minus!"
"plus!"
"copy!"
"invertIfCan"
"nullity"
"antisymmetric?"
"symmetric?"
"diagonal?"
"square?"
"lup_decomposition"
"mul_mv"
"mmul"
"triangular_multiply"
"lower_triangular_inverse"
"fractionFreeGauss!"
"elColumn2!"
"elRow2!"
"elRow1!"
"Omega"
"Psi"
"Chi"
"Phi"
"Upsilon"
"Tau"
"Sigma"
"Rho"
"Pi"
"Omicron"
"Xi"
"Nu"
"Mu"
"Lambda"
"Kappa"
"Iota"
"Theta"
"Eta"
"Zeta"
"Epsilon"
"Alpha"
"psi"
"chi"
"phi"
"upsilon"
"tau"
"sigma"
"rho"
"omicron"
"xi"
"nu"
"mu"
"lambda"
"kappa"
"iota"
"theta"
"eta"
"zeta"
"epsilon"
"gamma"
"beta"
"alpha"
"partial"
"resetNewGreek"
"newGreek"
"kroneckerProduct"
"kroneckerSum"
"positivePower"
"kronecker_prod1"
"twist"
"constantLeft"
"constantRight"
"curryLeft"
"curryRight"
"diag"
"curry"
"const"
"recur"
"id"
"nullary"
"comp"
"arg2"
"arg1"
"iter"
"blockSplit"
"bandMatrix"
"subMatrix"
"columns"
"columnMatrix"
"rows"
"rowMatrix"
"element"
"one?"
"rightPower"
"leftPower"
"leftRecip"
"rightRecip"
"m_inverse"
"pack_exps0"
"repack1"
"pack_exps"
"MPtoMPT"
"pack_modulus"
"canonicalIfCan"
"pseudoRem"
"algebraicGcd"
"zeroMatrix"
"identityMatrix"
"plus"
"matrixConcat3D"
"matrixDimensions"
"explicitEntries?"
"explicitlyEmpty?"
"lazy?"
"lazyEvaluate"
"frst"
"rst"
"numberOfComputedEntries"
"lexico"
"lyndon?"
"lyndon"
"lyndonIfCan"
"LyndonWordsList1"
"LyndonWordsList"
"LUInverse"
"LUSolve"
"LUDecomp"
"intoMatrix"
"linSolve"
"solveUniquely"
"hasSolution?"
"list"
"solveLinearPolynomialEquationByFractions"
"lcmCoef"
"loop"
"entries"
"true"
"false"
"directSum"
"symmetricPower"
"symmetricProduct"
"ge_minimal"
"gen_exp"
"testgt"
"testis"
"testlp"
"testfg"
"testsc"
"testfo"
"testro"
"testsb"
"testfr"
"testpd"
"testcx"
"testco"
"testcp"
"testlw"
"testln"
"testlc"
"testll"
"testf2"
"testfn"
"testnp"
"factor1"
"symmetricSquare"
"delta_deriv"
"delete"
"insert"
"sorted?"
"copyInto!"
"reverse!"
"sort!"
"listOfMonoms"
"makeTerm"
"makeMulti"
"nthExpon"
"nthFactor"
"makeUnit"
"rightMult"
"leftMult"
"mapExpon"
"mapGen"
"duplicates?"
"substitute"
"find_relation"
"extendedLLL"
"extendedLLL!"
"LLL"
"csolve_rmat"
"csolve_rf"
"csolve_pol"
"minShift"
"cartesianPower"
"topologicalSort"
"topologicalSort!"
"splitList"
"match"
"append"
"tails"
"setUnion"
"setIntersection"
"setDifference"
"eliminationSolve"
"eliminationGroebner"
"eliminationEquations"
"eliminationTransformations"
"blockElimination"
"setsubPencil!"
"setsubMatrix!"
"qsetelt!"
"rightIdentity"
"leftIdentity"
"transformColumns!"
"transformRows!"
"qscaleBlock!"
"qmultiplyColumn!"
"multiplyColumn!"
"qaddColumns!"
"addColumns!"
"swapColumns!"
"qswapColumns!"
"multiplyRow!"
"qmultiplyRow!"
"qaddRows!"
"addRows!"
"qswapRows!"
"swapRows!"
"insertRowsColumns"
"removeRowsColumns"
"subPencil"
"qrowIndices"
"qcolumnIndices"
"qnilpotent?"
"quppertriangular?"
"uppertriangular?"
"qdiagonal"
"qdiagonal?"
"qsemizero?"
"qzero?"
"nelem"
"qequal?"
"equal?"
"append!"
"qnew"
"reducedSystem"
"solveLinear"
"linearDependence"
"linearlyDependent?"
"lin_comb"
"lin_comb!"
"dehomogenize"
"complexLimit"
"library"
"pack!"
"close!"
"choosemon"
"intcompBasis"
"anticoord"
"coord"
"computeBasis"
"minPol"
"totolex"
"groebgen"
"linGenPos"
"Ei"
"Si"
"Ci"
"Shi"
"li"
"dilog"
"erf"
"erfi"
"fresnelS"
"fresnelC"
"belong?"
"squareFreeLexTriangular"
"lexTriangular"
"fglmIfCan"
"zeroDimensional?"
"LyndonBasis"
"LyndonCoordinates"
"identification"
"distFact"
"polCase"
"normalizeIfCan"
"trailingCoefficient"
"logicT"
"logicF"
"latticeMeetOfJoins"
"emptyLattice"
"meet"
"deductions"
"opType"
"toStringUnwrapped"
"latticeJoinOfMeets"
"laplace"
"parseLambda"
"isCompound?"
"isLambda?"
"isBoundNode?"
"isFreeNode?"
"getBoundValue"
"free?"
"subst"
"bind"
"unbind"
"toStringConven"
"kovacic"
"constantIfCan"
"constantKernel"
"argument"
"kernel"
"symbolIfCan"
"key?"
"keys"
"search"
"diffX"
"diffU"
"diffP"
"directions"
"lie"
"prolong"
"ground?"
"eqRep?"
"setFormats!"
"setFormat!"
"d"
"dX"
"dU"
"dP"
"differentials"
"contract"
"project"
"prolongMV"
"prolongSymbol"
"analyseSymbol"
"extractSymbol"
"setSimpMode"
"makeSystem"
"jacobiMatrix"
"printSys"
"ground"
"X"
"U"
"P"
"setNotation"
"getNotation"
"numIndVar"
"numDepVar"
"jetVariables"
"const?"
"class"
"formalDiff"
"formalDiff2"
"orderDim"
"freeOf?"
"leadingDer"
"sortLD"
"solveFor"
"dSubst"
"simpOne"
"simpMod"
"reduceMod"
"autoReduce"
"numerJP"
"multiIndex"
"repeatedIndex"
"r2m"
"m2r"
"allRepeated"
"type"
"weight"
"derivativeOf?"
"integrateIfCan"
"Pm"
"Pr"
"dimJ"
"dimS"
"index?"
"indices"
"entry?"
"fill!"
"swap!"
"do_liou"
"explogs2trigs"
"F2FG"
"FG2F"
"GF2FG"
"makeSeries"
"getRef"
"getStream"
"iExquo"
"taylorQuoByVar"
"iCompose"
"seriesToOutputForm"
"cPower"
"cRationalPower"
"cExp"
"cLog"
"cSin"
"cCos"
"cTan"
"cCot"
"cSec"
"cCsc"
"cAsin"
"cAcos"
"cAtan"
"cAcot"
"cAsec"
"cAcsc"
"cSinh"
"cCosh"
"cTanh"
"cCoth"
"cSech"
"cCsch"
"cAsinh"
"cAcosh"
"cAtanh"
"cAcoth"
"cAsech"
"cAcsch"
"checkRur"
"irreducibleRepresentation"
"dimensionOfIrreducibleRepresentation"
"complexIntegrate"
"complexExpand"
"approxSqrt"
"perfectSqrt"
"perfectSquare?"
"approxNthRoot"
"perfectNthRoot"
"perfectNthPower?"
"mkAnswer"
"ratpart"
"logpart"
"notelem"
"elem?"
"iprint"
"quadraticNonResidue"
"leadingSupport"
"constructOrdered"
"leadingTerm"
"inverseLaplace"
"monomialIntPoly"
"monomialIntegrate"
"lambintegrate"
"expintegrate"
"primintegrate"
"mkPrim"
"removeConstantTerm"
"vark"
"ksec"
"kmax"
"varselect"
"infieldIntegrate"
"internalIntegrate"
"integerIfCan"
"infieldint"
"pmintegrate"
"splitConstant"
"logextint"
"extendedint"
"polylog_int"
"monologextint"
"unkextint"
"diffextint"
"expextint"
"primextint"
"palgLODE"
"param_LODE"
"param_RDE"
"palgRDE"
"palgint"
"unitPart"
"HermiteIntegrate"
"sumOfKthPowerDivisors"
"sumOfDivisors"
"numberOfDivisors"
"moebiusMu"
"jacobi"
"harmonic"
"fibonacci"
"eulerPhi"
"divisors"
"chineseRemainder"
"carmichaelLambda"
"fsqrt"
"gen_ef"
"get_elliptics"
"palgLODE0"
"rationalize_ir"
"palgRDE0"
"palgint0"
"PollardSmallFactor"
"BasicMethod"
"lfintegrate"
"lfextendedint"
"solve_u"
"poly_int"
"li_int"
"interval"
"bitTruth"
"bitCoef"
"algextint_base"
"algextint"
"palgintegrate"
"algintegrate"
"algint"
"seedRandom"
"bit?"
"positiveRemainder"
"symmetricRemainder"
"inc"
"dec"
"mask"
"addmod"
"submod"
"mulmod"
"powmod"
"invmod"
"signAround"
"reduction"
"modularGcdPrimitive"
"makeEq"
"innerSolve"
"innerSolve1"
"generalInfiniteProduct"
"oddInfiniteProduct"
"evenInfiniteProduct"
"infiniteProduct"
"interpret"
"pretendOfType"
"atType"
"coerceToType"
"packageCall"
"interpret_in_new_env"
"binary"
"flatten"
"unparse"
"declare"
"compile"
"innerEigenvectors"
"solve1"
"charpol"
"incrementBy"
"increment"
"incidenceAlgebra"
"minimalPolynomial"
"normalElement"
"normal?"
"lookup"
"qPot"
"expPot"
"repSq"
"dAndcExp"
"xn"
"pol"
"setFieldInfo"
"merge2"
"merge_exponents"
"do_poly_integer"
"do_modular_solve"
"row_operation_modular"
"row_operation_base"
"generalizedInverse"
"proposition"
"parseIL"
"parseIL2"
"parseILTerm"
"flexibleArray"
"physicalLength"
"physicalLength!"
"shrinkable"
"removeRepeats!"
"generalizedEigenvectors"
"eigenvectors"
"eigenvalues"
"generalizedEigenvector"
"eigenvector"
"numberOfMonomials"
"primaryDecomp"
"radical"
"zeroDimPrimary?"
"zeroDimPrime?"
"element?"
"in?"
"inRadical?"
"zeroDim?"
"quotient"
"generalPosition"
"backOldPos"
"leadingIdeal"
"ideal"
"groebnerIdeal"
"groebner?"
"saturate"
"relationsIdeal"
"fullDisplay"
"mapBivariate"
"mapMatrixIfCan"
"mapUnivariateIfCan"
"mapUnivariate"
"moduleSum"
"idealiserMatrix"
"idealiser"
"leastPower"
"divideIfCan!"
"matrixGcd"
"listConjugateBases"
"factorList"
"exprex"
"antipode"
"homologyGroup"
"homology0"
"homologyz"
"homologyzz"
"homologyc2"
"homologyzc2"
"dispGenerators"
"map!"
"any?"
"every?"
"count"
"parts"
"members"
"hex"
"lintgcd"
"gcdcofactprim"
"gcdcofact"
"gcdprim"
"heap"
"reorder"
"inHallBasis?"
"lfunc"
"update!"
"hash"
"hashUpdate!"
"HankelMatrix"
"guessHolo"
"guessADE"
"guessRat"
"guessPRec"
"guessRec"
"diffHP"
"shiftHP"
"substHP"
"algDepHP"
"guessPade"
"guessAlg"
"guessFE"
"guessAlgDep"
"guessBinRat"
"guessExpRat"
"guess"
"iiretractVar"
"iim2"
"EXPRR2F"
"F2EXPRR"
"groupPresentation"
"refactor"
"directProduct"
"toPermutationIfCan"
"genericPosition"
"testDim"
"groebSolve"
"graphImage"
"sendGraphImage"
"makeGraphImage"
"pointLists"
"ranges"
"component"
"appendPoint"
"putColorInfo"
"adaptive"
"drawToScale"
"clipPointsDefault"
"firstSubsetGray"
"nextSubsetGray"
"monomials"
"totalDegree"
"totalDegreeSorted"
"primitiveMonomials"
"GospersMethod"
"maxDerivative"
"maxShift"
"maxSubst"
"maxPower"
"homogeneous"
"Somos"
"maxLevel"
"maxDegree"
"maxMixedDegree"
"allDegrees"
"safety"
"checkExtraValues"
"one"
"functionName"
"functionNames"
"variableName"
"indexName"
"displayKind"
"checkOptions"
"option"
"leadingExponent"
"leadingIndex"
"build"
"multMonom"
"completeHensel"
"HenselLift"
"infsum"
"removeZeros"
"moebiusMatrix"
"canonicalMoebiusFunction"
"generalizedMoebiusFunction"
"testModulus"
"solveid"
"tablePow"
"compBound"
"gnuDraw"
"leftUnits"
"rightUnits"
"generic"
"leftRankPolynomial"
"genericLeftMinimalPolynomial"
"genericLeftTrace"
"genericLeftNorm"
"rightRankPolynomial"
"genericRightMinimalPolynomial"
"genericRightTrace"
"genericRightNorm"
"genericLeftTraceForm"
"genericLeftDiscriminant"
"genericRightTraceForm"
"genericRightDiscriminant"
"conditionsForIdempotents"
"gcdDecomposition"
"gcdBasis"
"makeCrit"
"critpOrder"
"prinb"
"prinpolINFO"
"fprindINFO"
"prindINFO"
"prinshINFO"
"lepol"
"minGbasis"
"updatD"
"updatF"
"redPo"
"critMonD1"
"critMTonD1"
"critBonD"
"critB"
"critM"
"critT"
"gbasisExtend"
"gbasis"
"credPol"
"groebnerFactorize"
"factorGroebnerBasis"
"euclideanGroebner"
"euclideanNormalForm"
"sumSquares"
"safetyMargin"
"safeFloor"
"safeCeiling"
"fillPascalTriangle"
"sizePascalTriangle"
"rangePascalTriangle"
"pascalTriangle"
"factorsOfDegree"
"factorOfDegree"
"degreePartition"
"shiftRoots"
"scaleRoots"
"infinityNorm"
"quadraticNorm"
"singleFactorBound"
"rootBound"
"bombieriNorm"
"beauzamyBound"
"btwFact"
"henselFact"
"tryFunctionalDecomposition"
"tryFunctionalDecomposition?"
"eisensteinIrreducible?"
"useEisensteinCriterion"
"useEisensteinCriterion?"
"useSingleFactorBound"
"useSingleFactorBound?"
"modularFactor"
"numberOfFactors"
"stopMusserTrials"
"musserTrials"
"makeFR"
"separate_factors"
"processTemplate"
"fortranLiteralLine"
"fortranLiteral"
"fortranCarriageReturn"
"scalarTypeOf"
"dimensionsOf"
"external?"
"fortranReal"
"fortranDouble"
"fortranInteger"
"fortranLogical"
"fortranComplex"
"fortranDoubleComplex"
"fortranCharacter"
"double?"
"complex?"
"doubleComplex?"
"character?"
"logical?"
"newReduc"
"bringDown"
"coerce_Q"
"retract_Q"
"iLambertW"
"iiPolylog"
"iiHypergeometricF"
"iAiryBiPrime"
"iAiryBi"
"iAiryAiPrime"
"iAiryAi"
"iiAiryBiPrime"
"iiAiryBi"
"iiAiryAiPrime"
"iiAiryAi"
"iiBesselK"
"iiBesselI"
"iiBesselY"
"iiBesselJ"
"iipolygamma"
"iidigamma"
"iiBeta"
"iiconjugate"
"iiabs"
"iiGamma"
"lambert_inverse_series"
"lambert_via_newton2"
"lambert_via_newton1"
"rabs"
"li2"
"logGamma"
"makeSin"
"makeCos"
"internalIntegrate0"
"applyQuote"
"isMult"
"algtower"
"cardinality"
"universe"
"my_digamma"
"powToUPS"
"integ_df"
"integt"
"integ"
"atan1"
"localAbs"
"exprToPS"
"exprToGenUPS"
"exprToUPS"
"exprToXXP"
"leftDiscriminant"
"rightDiscriminant"
"leftTraceMatrix"
"rightTraceMatrix"
"leftRegularRepresentation"
"rightRegularRepresentation"
"represents"
"module"
"minimize"
"randomLC"
"traceMatrix"
"regularRepresentation"
"factorFraction"
"map_preserving"
"nilFactor"
"factors"
"irreducibleFactor"
"primeFactor"
"sqfrFactor"
"flagFactor"
"unit"
"unitNormalize"
"mergeFactors"
"bits"
"increasePrecision"
"decreasePrecision"
"discreteLog"
"primeFrobenius"
"fullPartialFraction"
"polyPart"
"fracPart"
"convert_to_decimal"
"convert_mr"
"general_mr"
"floating_mr"
"fixed_mr"
"format"
"setDefault!"
"operatorHandlers"
"formatStep"
"topFortranOutputStack"
"pushFortranOutputStack"
"popFortranOutputStack"
"showFortranOutputStack"
"clearFortranOutputStack"
"deepExpand"
"shallowExpand"
"functionGraph"
"filename"
"directory"
"extension"
"exists?"
"readable?"
"writable?"
"environment"
"defaultPrologue"
"defaultEpilogue"
"minPrecedence"
"maxPrecedence"
"formatExpression"
"formatInteger"
"formatFloat"
"formatString"
"formatSymbol"
"formatFunctionSymbol"
"formatFunction"
"parenthesize"
"parenthesizeIf"
"nothing"
"formatConstant"
"precedence"
"nary"
"naryPlus"
"theMap"
"altsupersub"
"numberOfPrimes"
"fraction"
"hclf"
"hcrf"
"overlap"
"moebiusFunction"
"support"
"minus"
"realRoots"
"complexRoots"
"complexSolve"
"relerror"
"rationalApproximation"
"log2"
"log10"
"exp1"
"outputFloating"
"outputFixed"
"outputGeneral"
"outputSpacing"
"get_output_mode"
"set_output_mode"
"shellSort"
"heapSort"
"quickSort"
"LiePoly"
"finiteLattice"
"someBasis"
"leftTrace"
"rightTrace"
"leftNorm"
"rightNorm"
"leftCharacteristicPolynomial"
"rightCharacteristicPolynomial"
"commutative?"
"antiCommutative?"
"associative?"
"antiAssociative?"
"leftAlternative?"
"rightAlternative?"
"flexible?"
"alternative?"
"powerAssociative?"
"jacobiIdentity?"
"lieAdmissible?"
"jordanAdmissible?"
"noncommutativeJordanAlgebra?"
"jordanAlgebra?"
"lieAlgebra?"
"associatorDependence"
"leftMinimalPolynomial"
"rightMinimalPolynomial"
"leftUnit"
"rightUnit"
"deserialize"
"serialize"
"open"
"reopen!"
"iomode"
"read!"
"write!"
"flush"
"addObject!"
"addArrow!"
"getVertices"
"getVertexIndex"
"getArrows"
"initial"
"terminal"
"cycleOpen"
"cycleClosed"
"kgraph"
"isDirectSuccessor?"
"isGreaterThan?"
"isFixPoint?"
"arrowName"
"getArrowIndex"
"inDegree"
"outDegree"
"nodeFromNode"
"nodeToNode"
"arrowsFromNode"
"arrowsToNode"
"nodeFromArrow"
"nodeToArrow"
"arrowsFromArrow"
"arrowsToArrow"
"routeNodes"
"routeArrows"
"spanningTreeArrow"
"spanningForestArrow"
"spanningTreeNode"
"spanningForestNode"
"loopsNodes"
"loopsAtNode"
"loopsArrows"
"isAcyclic?"
"incidenceMatrix"
"adjacencyMatrix"
"laplacianMatrix"
"distanceMatrix"
"isFunctional?"
"subdiagramSvg"
"diagramSvg"
"diagramsSvg"
"deepDiagramSvg"
"diagramWidth"
"diagramHeight"
"looseEquals"
"mapContra"
"rootOfIrreduciblePoly"
"reducedQPowers"
"leastAffineMultiple"
"nextPrimitiveNormalPoly"
"nextNormalPrimitivePoly"
"nextNormalPoly"
"nextPrimitivePoly"
"nextIrreduciblePoly"
"cnlexSmaller?"
"nlexSmaller?"
"clexSmaller?"
"lexSmaller?"
"createPrimitiveNormalPoly"
"createNormalPrimitivePoly"
"createNormalPoly"
"createPrimitivePoly"
"createIrreduciblePoly"
"numberOfNormalPoly"
"numberOfPrimitivePoly"
"numberOfIrreduciblePoly"
"primitive?"
"getMultiplicationTable"
"getMultiplicationMatrix"
"sizeMultiplication"
"factorsOfCyclicGroupSize"
"tableForDiscreteLogarithm"
"createPrimitiveElement"
"representationType"
"generalInterpolation"
"genVectorStream2"
"genVectorStream"
"qShiftC"
"qShiftAction"
"DiffC"
"DiffAction"
"ShiftC"
"ShiftAction"
"generalCoefficient"
"fffg"
"createLowComplexityNormalBasis"
"createLowComplexityTable"
"createMultiplicationMatrix"
"createMultiplicationTable"
"createZechTable"
"getZechTable"
"genus"
"absolutelyIrreducible?"
"rationalPoint?"
"branchPointAtInfinity?"
"branchPoint?"
"singularAtInfinity?"
"singular?"
"ramifiedAtInfinity?"
"ramified?"
"integralBasisAtInfinity"
"integralAtInfinity?"
"special_order"
"integral?"
"complementaryBasis"
"normalizeAtInfinity"
"reduceBasisAtInfinity"
"integralMatrix"
"inverseIntegralMatrix"
"integralMatrixAtInfinity"
"inverseIntegralMatrixAtInfinity"
"yCoordinates"
"integralCoordinates"
"integralRepresents"
"integralDerivationMatrix"
"elliptic"
"hyperelliptic"
"algSplitSimple"
"nonSingularModel"
"rationalPoints"
"sn2"
"kprod"
"landen"
"landen2"
"landen1"
"modularInvariantJ"
"weierstrassInvariants"
"weierstrassHalfPeriods"
"log_series"
"exp_series"
"exp_frac"
"divisor"
"principal?"
"finiteBasis"
"lSpaceBasis"
"enableDebugOutput"
"disableDebugOutput"
"toggleDebugOutput"
"enableAlternativeOutput"
"disableAlternativeOutput"
"toggleAlternativeOutput"
"minimal?"
"mutable?"
"qregular?"
"scalar?"
"regular?"
"polynomial?"
"appendSupport!"
"pencil"
"swapRowsColumns!"
"addRowsColumns!"
"addColumnsRows!"
"blockStructure"
"refined?"
"admissibleLinearSystem"
"linearization"
"representation"
"transformationMatrix"
"normalizeRHS!"
"normalizePLS!"
"normalizeDIAG!"
"normalize!"
"solutionVector"
"columnSpan"
"rowSpan"
"scaleALS"
"addALS"
"multiplyALS"
"invertALS"
"invertSTD"
"summands"
"leftFamily"
"rightFamily"
"ratexprInverse"
"ratexpr"
"leftFactor"
"rightFactor"
"factorize"
"factorizationTransformations"
"factorizationEquations"
"factorizationGroebner"
"factorizationSolve"
"refineUR!"
"extendedALS"
"normalALS"
"leftMinimization"
"rightMinimization"
"addMIN"
"multiplyMIN"
"invertMIN"
"setRefined!"
"refine!"
"refinementTransformations"
"refinementEquations"
"refinementGroebner"
"refinementSolve"
"get_fort_indent"
"get_used_intrinsics"
"clear_used_intrinsics"
"newFortranTempVar"
"checkType"
"indentFortLevel"
"fort_format_types"
"fortFormatTypeLines"
"fortFormatHead"
"dispStatement"
"displayLines"
"changeExprLength"
"getStatement"
"expression2Fortran"
"statement2Fortran"
"expression2Fortran1"
"do_with_error_env1"
"do_with_error_env2"
"do_with_error_env3"
"fort_clean_lines"
"identitySquareMatrix"
"zeroSquareMatrix"
"zeroVector"
"sin?"
"forLoop"
"whileLoop"
"repeatUntilLoop"
"gotoJump"
"continue"
"comment"
"call"
"returns"
"cond"
"block"
"stop"
"save"
"printStatement"
"common"
"operation"
"code"
"printCode"
"getCode"
"setLabelValue"
"createNormalElement"
"linearAssociatedExp"
"linearAssociatedOrder"
"linearAssociatedLog"
"mapExponents"
"pomopo!"
"fmecg"
"binomThmExpt"
"subst_var"
"to_UP"
"ran"
"normalDeriv"
"raisePolynomial"
"lowerPolynomial"
"completeEval"
"getMult"
"exponentialOrder"
"tubePlot"
"constantToUnaryFunction"
"replaceDiffs"
"number?"
"setSimplifyDenomsFlag"
"getSimplifyDenomsFlag"
"sizeLess?"
"euclideanSize"
"extendedEuclidean"
"multiEuclidean"
"distribute"
"mainKernel"
"kernels"
"tower"
"operators"
"minPoly"
"error"
"swap"
"leftZero"
"rightZero"
"leftOne"
"rightOne"
"factorAndSplit"
"unitNormal"
"unitCanonical"
"associates?"
"unit?"
"ellipticRJ"
"ellipticRF"
"ellipticRD"
"ellipticRC"
"lin_sol"
"sncndn"
"delete!"
"select!"
"irootDep"
"tanQ"
"rmap"
"rootNormalize"
"validExponential"
"realElementary"
"realLiouvillian"
"rischNormalize"
"do_quo"
"poly_factor"
"localReal?"
"specialTrigs"
"iiacsch"
"iiasech"
"iiacoth"
"iiatanh"
"iiacosh"
"iiasinh"
"iicsch"
"iisech"
"iicoth"
"iitanh"
"iicosh"
"iisinh"
"iiacsc"
"iiasec"
"iiacot"
"iiatan"
"iiacos"
"iiasin"
"iicsc"
"iisec"
"iicot"
"iitan"
"iicos"
"iisin"
"iilog"
"iiexp"
"iisqrt3"
"iisqrt2"
"exponents"
"Nul"
"makeVariable"
"JContinuedFraction"
"tubeRadius"
"tubePoints"
"space"
"var2Steps"
"var1Steps"
"curveColorPalette"
"pointColorPalette"
"toScale"
"style"
"clipBoolean"
"clip"
"pointColor"
"curveColor"
"colorFunction"
"range"
"option?"
"draw"
"setClipValue"
"setImagSteps"
"setRealSteps"
"drawComplexVectorField"
"drawComplex"
"makeObject"
"recolor"
"insertTop!"
"insertBottom!"
"extractTop!"
"extractBottom!"
"differentialVariables"
"weights"
"isobaric?"
"leader"
"separant"
"shanksDiscLogAlgorithm"
"datalist"
"previous"
"next"
"setprevious!"
"setnext!"
"R1_to_R2_coercion"
"mapall"
"distributionByMoments"
"distributionByEvenMoments"
"distributionByClassicalCumulants"
"distributionByFreeCumulants"
"distributionByBooleanCumulants"
"distributionByJacobiParameters"
"booleanCumulantFromJacobi"
"distributionByMonotoneCumulants"
"freeMultiplicativeConvolution"
"arcsineDistribution"
"bernoulliDistribution01"
"freePoissonDistribution"
"wignerDistribution"
"poissonDistribution"
"gaussianDistribution"
"moment"
"classicalCumulant"
"freeCumulant"
"booleanCumulant"
"moments"
"classicalCumulants"
"freeCumulants"
"booleanCumulants"
"hankelDeterminants"
"monotoneCumulants"
"jacobiParameters"
"orthogonalPolynomials"
"classicalConvolution"
"freeConvolution"
"booleanConvolution"
"monotoneConvolution"
"orthogonalConvolution"
"subordinationConvolution"
"sayLength"
"say"
"copies"
"newLine"
"multiplicative?"
"additive?"
"dioSolve"
"dictionary"
"expa"
"expb"
"exponenta"
"exponentb"
"rotatex"
"rotatey"
"rotatez"
"directedGraph"
"hypergeometric0F1"
"qlog"
"qsqrt"
"doubleFloatFormat"
"checkForZero"
"computeInt"
"ignore?"
"log_plus_1"
"leadingBasisTerm"
"homogeneous?"
"totalDifferential"
"exteriorDifferential"
"dequeue"
"circle"
"deltaComplex"
"triangle"
"faceMap"
"cyclotomic_roots"
"innerint"
"decimal"
"doubleResultant"
"cocyclotomic_decomposition"
"cyclotomic_decomposition"
"cyclotomic?"
"inverse_cyclotomic"
"cyclotomic_array"
"skewSFunction"
"SFunction"
"wreath"
"cup"
"cap"
"dihedral"
"cyclic"
"alternating"
"elementary"
"powerSum"
"coerceP"
"cubicalComplex"
"addCube"
"computeCycleEntry"
"computeCycleLength"
"cycleElt"
"startPolynomial"
"setErrorBound"
"schwerpunkt"
"rootRadius"
"reciprocalPolynomial"
"pleskenSplit"
"graeffe"
"divisorCascade"
"complexZeros"
"multiEuclideanTree"
"modTree"
"conical"
"toroidal"
"bipolarCylindrical"
"bipolar"
"oblateSpheroidal"
"prolateSpheroidal"
"ellipticCylindrical"
"paraboloidal"
"parabolicCylindrical"
"parabolic"
"spherical"
"cylindrical"
"polar"
"reducedContinuedFraction"
"partialNumerators"
"partialDenominators"
"partialQuotients"
"reducedForm"
"approximants"
"convergents"
"numerators"
"denominators"
"solid?"
"solid"
"writePackage"
"writeCategory"
"imaginary"
"complex"
"polarCoordinates"
"smaller?"
"mkcomm"
"factorials"
"summation"
"catalan"
"stirling2"
"stirling1"
"permutation"
"distinct_partition"
"multinomial"
"factorial"
"ipow"
"iidprod"
"iidsum"
"iipow"
"iiperm"
"iibinom"
"iifact"
"red"
"yellow"
"green"
"blue"
"numberOfHues"
"coChainComplex"
"validate"
"coboundary"
"coproduct"
"counit"
"clipWithRanges"
"clipParametric"
"constant_subspace"
"nullSpaceOverConstants"
"solveLinearOverConstants"
"particularSolutionOverConstants"
"linearDependenceOverConstants"
"linearlyDependentOverConstants?"
"e"
"ee"
"multivector"
"eFromBinaryMap"
"ePseudoscalar"
"toTable"
"lc"
"rc"
"gradeInvolution"
"conj"
"setMode"
"find"
"removeDuplicates"
"complete2"
"bound"
"gaugeHilbert"
"gauge"
"arbFunctions"
"alphaHilbert"
"hilbert"
"stirling"
"setRedMode"
"setOutMode"
"chvar"
"goodPoint"
"rootPoly"
"radPoly"
"mkIntegral"
"char_pol_via_berkovitz"
"char_pol_via_den_interpolation"
"det_via_common_denominator"
"char_pol_via_interpolation"
"char_pol"
"danilewski"
"ord"
"char"
"underscore"
"newline"
"digit?"
"hexDigit?"
"alphabetic?"
"upperCase?"
"lowerCase?"
"alphanumeric?"
"chainComplex"
"transition_matrices"
"cubicalFacet"
"getIntervals"
"setMult"
"makeCell"
"mainVariableOf"
"variablesOf"
"projection"
"simpleCells"
"charClass"
"digit"
"hexDigit"
"alphabetic"
"alphanumeric"
"reshape"
"kroneckerDelta"
"leviCivitaSymbol"
"ravel"
"unravel"
"Aleph"
"countable?"
"generalizedContinuumHypothesisAssumed?"
"generalizedContinuumHypothesisAssumed"
"squareFreeBasis"
"specialise"
"principalSubResultantSet"
"resultantSet"
"discriminantSet"
"coefficientSet"
"projectionSet"
"cylindricalDecomposition"
"setPosition"
"subtractIfCan"
"binaryTree"
"binaryTournament"
"node"
"nand"
"nor"
"binarySearchTree"
"insertRoot!"
"sublis_formal"
"downcase"
"search_operations_libdb"
"ops_from_libdb"
"ops_from_exports"
"filter_symbols"
"filter_ops"
"do_match"
"convert_pattern"
"search_opl"
"group_by_implementation"
"group_by_condition"
"group_by_origin"
"search_general"
"search_documentation"
"search_operations"
"search_constructors"
"all_constructors"
"simp_ops_conditions"
"operations"
"parents"
"ancestors"
"exports"
"exposed_constructor?"
"default_name?"
"constructor_signature"
"constructor_name?"
"constructor_kind"
"constructor_form"
"constructor_documentation"
"noLinearFactor?"
"brillhartTrials"
"brillhartIrreducible?"
"setleft!"
"setright!"
"constantOpIfCan"
"constantOperator"
"derivative"
"properties"
"arity"
"nullary?"
"unary?"
"nary?"
"equality"
"comparison"
"input"
"has?"
"assert"
"deleteProperty!"
"property"
"setProperty"
"setProperties"
"test"
"T$"
"read"
"_|_"
"starts"
"extract!"
"inspect"
"bezoutDiscriminant"
"bezoutResultant"
"subresultants"
"bezoutMatrix"
"subSylvesterMatrix"
"sylvesterMatrix"
"balancedBinaryTree"
"setleaves!"
"mapUp!"
"mapDown!"
"readIfCan"
"balancedFactorisation"
"morphism"
"arrayStack"
"associatedEquations"
"uncouplingMatrices"
"associatedSystem"
"oneDimensionalArray"
"array2"
"rowSlice"
"colSlice"
"setColumn!"
"squareTop"
"horizConcat"
"vertConcat"
"blockConcat"
"vertSplit"
"applyRules"
"any"
"domainOf"
"objectOf"
"dom"
"obj"
"showTypeInOutput"
"trueEqual"
"radicalOfLeftTraceForm"
"basisOfCentroid"
"basisOfRightNucloid"
"basisOfLeftNucloid"
"basisOfCenter"
"basisOfNucleus"
"basisOfMiddleNucleus"
"basisOfRightNucleus"
"basisOfLeftNucleus"
"basisOfRightAnnihilator"
"basisOfLeftAnnihilator"
"basisOfCommutingElements"
"biRank"
"weakBiRank"
"doubleRank"
"rightRank"
"leftRank"
"rootKerSimp"
"rootSimp"
"rootProduct"
"rootPower"
"rootFactor"
"ratPoly"
"ratDenom"
"rootSplit"
"knownInfBasis"
"doublyTransitive?"
"assoc"
"qinterval"
"error?"
"contains?"
"eq?"
"size?"
"iroot"
"droot"
"inrootof"
"rootSum"
"makeSketch"
"rootsOf"
"zeroOf"
"zerosOf"
"opposite?"
"OneDimensionalArrayAggregate"
"A1AGG"
"AbelianGroup"
"ABELGRP"
"AbelianMonoid"
"ABELMON"
"AbelianSemiGroup"
"ABELSG"
"AlgebraicallyClosedField"
"ACF"
"AlgebraicallyClosedFunctionSpace"
"ACFS"
"PlaneAlgebraicCurvePlot"
"ACPLOT"
"AlgebraicFunction"
"AF"
"Aggregate"
"AGG"
"ArcHyperbolicFunctionCategory"
"AHYP"
"AIntervalCategory"
"AINTCAT"
"AInterval"
"AINTRVL"
"AssociationListAggregate"
"ALAGG"
"Algebra"
"ALGEBRA"
"AlgFactor"
"ALGFACT"
"AlgebraicFunctionField"
"ALGFF"
"AlgebraicManipulations"
"ALGMANIP"
"AlgebraicMultFact"
"ALGMFACT"
"AlgebraPackage"
"ALGPKG"
"AlgebraGivenByStructuralConstants"
"ALGSC"
"AssociationList"
"ALIST"
"AbelianMonoidRing"
"AMR"
"AlgebraicNumber"
"AN"
"AnonymousFunction"
"ANON"
"AntiSymm"
"ANTISYM"
"Any"
"ANY"
"AnyFunctions1"
"ANY1"
"ApplyUnivariateSkewPolynomial"
"APPLYORE"
"ApplyRules"
"APPRULE"
"AbelianProductCategory"
"APRODC"
"TwoDimensionalArrayCategory"
"ARR2CAT"
"OneDimensionalArray"
"ARRAY1"
"OneDimensionalArrayFunctions2"
"ARRAY12"
"TwoDimensionalArray"
"ARRAY2"
"TwoDimensionalArrayFunctions"
"ARRAY22"
"AssociatedEquations"
"ASSOCEQ"
"ArrayStack"
"ASTACK"
"additiveValuation"
"ATADDVA"
"Approximate"
"ATAPPRO"
"arbitraryExponent"
"ATARBEX"
"arbitraryPrecision"
"ATARBPR"
"canonicalsClosed"
"ATCANCL"
"Canonical"
"ATCANON"
"CommutativeStar"
"ATCS"
"canonicalUnitNormal"
"ATCUNOR"
"finiteAggregate"
"ATFINAG"
"lazyRepresentation"
"ATLR"
"multiplicativeValuation"
"ATMULVA"
"noZeroDivisors"
"ATNZDIV"
"ArcTrigonometricFunctionCategory"
"ATRIG"
"shallowlyMutable"
"ATSHMUT"
"TwoSidedRecip"
"ATTWSR"
"unitsKnown"
"ATUNIKN"
"VariablesCommuteWithCoefficients"
"ATVCWC"
"Automorphism"
"AUTOMOR"
"BalancedFactorisation"
"BALFACT"
"BasicFile"
"BASFILE"
"BasicType"
"BASTYPE"
"BalancedBinaryTree"
"BBTREE"
"BoundedDistributiveLattice"
"BDISTL"
"BezoutMatrix"
"BEZOUT"
"BezoutMatrixWrapper"
"BEZOUT2"
"BagAggregate"
"BGAGG"
"Bialgebra"
"BIALG"
"BiCPO"
"BICPO"
"BinaryExpansion"
"BINARY"
"Bits"
"BITS"
"BitStreamFrame"
"BITST"
"BoundedJoinSemilattice"
"BJOIN"
"BasicKeyedAccessFile"
"BKAFILE"
"BoundedLattice"
"BLAT"
"BoundedMeetSemilattice"
"BMEET"
"BiModule"
"BMODULE"
"Boolean"
"BOOLEAN"
"BasicOperator"
"BOP"
"BasicOperatorFunctions1"
"BOP1"
"BoundIntegerRoots"
"BOUNDZRO"
"BalancedPAdicInteger"
"BPADIC"
"BalancedPAdicRational"
"BPADICRT"
"BinaryRecursiveAggregate"
"BRAGG"
"BrillhartTests"
"BRILL"
"BrowserInformation"
"BRINFO"
"BinarySearchTree"
"BSTREE"
"BitAggregate"
"BTAGG"
"BinaryTreeCategory"
"BTCAT"
"BinaryTournament"
"BTOURN"
"BinaryTree"
"BTREE"
"CancellationAbelianMonoid"
"CABMON"
"CachableSet"
"CACHSET"
"CylindricalAlgebraicDecompositionPackage"
"CAD"
"CylindricalAlgebraicDecompositionUtilities"
"CADU"
"CardinalNumber"
"CARD"
"CartesianTensor"
"CARTEN"
"CartesianTensorFunctions2"
"CARTEN2"
"CharacterClass"
"CCLASS"
"CommonDenominator"
"CDEN"
"ComplexDoubleFloatMatrix"
"CDFMAT"
"ComplexDoubleFloatVector"
"CDFVEC"
"Cell"
"CELL"
"CubicalFacet"
"CFACET"
"CombinatorialFunctionCategory"
"CFCAT"
"ChainComplex"
"CHAINC"
"Character"
"CHAR"
"CharacteristicNonZero"
"CHARNZ"
"CharacteristicPolynomialPackage"
"CHARPOL"
"CharacteristicPolynomial"
"CHARPOL0"
"CharacteristicPolynomial2"
"CHARPOL2"
"CharacteristicPolynomial3"
"CHARPOL3"
"CharacteristicPolynomial4"
"CHARPOL4"
"CharacteristicZero"
"CHARZ"
"ChangeOfVariable"
"CHVAR"
"ComplexIntegerSolveLinearPolynomialEquation"
"CINTSLPE"
"CartanKuranishi"
"CKP"
"Collection"
"CLAGG"
"CliffordAlgebra"
"CLIF"
"ConstantLinearDependence"
"CLINDEP"
"TwoDimensionalPlotClipping"
"CLIP"
"ComplexRootPackage"
"CMPLXRT"
"Coalgebra"
"COALG"
"CoChainComplex"
"COCHNC"
"CoDcpo"
"CODCPO"
"Color"
"COLOR"
"CombinatorialFunction"
"COMBF"
"IntegerCombinatoricFunctions"
"COMBINAT"
"CombinatorialOpsCategory"
"COMBOPC"
"Commutator"
"COMM"
"CommonOperators"
"COMMONOP"
"CommuteUnivariatePolynomialCategory"
"COMMUPC"
"Comparable"
"COMPAR"
"ComplexCategory"
"COMPCAT"
"compCode"
"COMPCODE"
"Complex"
"COMPLEX"
"ComplexFunctions2"
"COMPLEX2"
"ComplexPattern"
"COMPLPAT"
"SubSpaceComponentProperty"
"COMPPROP"
"compUtil"
"COMPUTIL"
"CommutativeRing"
"COMRING"
"ContinuedFraction"
"CONTFRAC"
"CoordinateSystems"
"COORDSYS"
"CharacteristicPolynomialInMonogenicalAlgebra"
"CPIMA"
"ComplexPatternMatch"
"CPMATCH"
"CRApackage"
"CRAPACK"
"ComplexRootFindingPackage"
"CRFP"
"CyclicStreamTools"
"CSTTOOLS"
"ComplexTrigonometricManipulations"
"CTRIGMNP"
"FiniteCubicalComplex"
"CUBEC"
"CubicalComplexFactory"
"CUBECF"
"CoerceVectorMatrixPackage"
"CVMP"
"CyclicGroup"
"CYCGRP"
"CycleIndicators"
"CYCLES"
"CyclotomicUtilities"
"CYCLOT2"
"Database"
"DBASE"
"DoubleResultantPackage"
"DBLRESP"
"Dcpo"
"DCPO"
"DecimalExpansion"
"DECIMAL"
"ElementaryFunctionDefiniteIntegration"
"DEFINTEF"
"RationalFunctionDefiniteIntegration"
"DEFINTRF"
"DegreeReductionPackage"
"DEGRED"
"DeltaComplex"
"DELTAC"
"DeltaComplexFactory"
"DELTCF"
"Dequeue"
"DEQUEUE"
"DeRhamComplex"
"DERHAM"
"DoubleFloatElementaryFunctions"
"DFELEM"
"DefiniteIntegrationTools"
"DFINTTLS"
"DoubleFloat"
"DFLOAT"
"DoubleFloatMatrix"
"DFMAT"
"DoubleFloatSpecialFunctions"
"DFSFUN"
"DoubleFloatSpecialFunctions2"
"DFSFUN2"
"DoubleFloatVector"
"DFVEC"
"DirectedGraph"
"DGRPH"
"DenavitHartenbergMatrix"
"DHMATRIX"
"Dictionary"
"DIAGG"
"DifferentialExtension"
"DIFEXT"
"DifferentialRing"
"DIFRING"
"DihedralGroup"
"DIHGRP"
"DictionaryOperations"
"DIOPS"
"DiophantineSolutionPackage"
"DIOSP"
"DirectProductCategory"
"DIRPCAT"
"DirectProduct"
"DIRPROD"
"DirectProductFunctions2"
"DIRPROD2"
"DirichletRing"
"DIRRING"
"DisplayPackage"
"DISPLAY"
"DistributionCategory"
"DISTCAT"
"DistributionPackage"
"DISTEX"
"DistributiveLattice"
"DISTLAT"
"DistributionPolynomialPackage"
"DISTPOL"
"Distribution"
"DISTRO"
"DistributionFunctions2"
"DISTRO2"
"DivisionRing"
"DIVRING"
"DistributedJetBundlePolynomial"
"DJBP"
"DoublyLinkedAggregate"
"DLAGG"
"DataList"
"DLIST"
"DiscreteLogarithmPackage"
"DLP"
"DistributedMultivariatePolynomial"
"DMP"
"DirectProductMatrixModule"
"DPMM"
"DirectProductModule"
"DPMO"
"DifferentialPolynomialCategory"
"DPOLCAT"
"DequeueAggregate"
"DQAGG"
"TopLevelDrawFunctions"
"DRAW"
"TopLevelDrawFunctionsForCompiledFunctions"
"DRAWCFUN"
"TopLevelDrawFunctionsForAlgebraicCurves"
"DRAWCURV"
"DrawComplex"
"DRAWCX"
"DrawNumericHack"
"DRAWHACK"
"TopLevelDrawFunctionsForPoints"
"DRAWPT"
"DrawOption"
"DROPT"
"DrawOptionFunctions0"
"DROPT0"
"DrawOptionFunctions1"
"DROPT1"
"DifferentialSparseMultivariatePolynomial"
"DSMP"
"DistributionContinuedFractionPackage"
"DSTCFPG"
"DifferentialVariableCategory"
"DVARCAT"
"ExtAlgBasis"
"EAB"
"ElementaryFunction"
"EF"
"ExpressionFactorPolynomial"
"EFACTOR"
"ElementaryFunctionsGeneralizedUnivariatePowerSeries"
"EFGUSER"
"ElementaryFunctionStructurePackage"
"EFSTRUC"
"ElementaryFunctionsUnivariateLaurentSeries"
"EFULS"
"ElementaryFunctionsUnivariatePuiseuxSeries"
"EFUPXS"
"ExtensibleLinearAggregate"
"ELAGG"
"ElementaryFunctionCategory"
"ELEMFUN"
"EllipticFunctionsUnivariateTaylorSeries"
"ELFUTS"
"ExpressionLinearSolve"
"ELINSOL"
"DoubleFloatEllipticIntegrals"
"ELIPIDF"
"Eltable"
"ELTAB"
"EltableAggregate"
"ELTAGG"
"EuclideanModularRing"
"EMR"
"EntireRing"
"ENTIRER"
"EigenPackage"
"EP"
"Equation"
"EQ"
"EquationFunctions2"
"EQ2"
"EqTable"
"EQTBL"
"ErrorIndicator"
"ERRIND"
"ErrorFunctions"
"ERROR"
"ExpressionSpace"
"ES"
"ExpressionSpaceFunctions1"
"ES1"
"ExpressionSpaceFunctions2"
"ES2"
"ExpressionSpace2"
"ESC2"
"EuclideanDomain"
"EUCDOM"
"Evalable"
"EVALAB"
"EvaluateCycleIndicators"
"EVALCYC"
"Exit"
"EXIT"
"Export3D"
"EXP3D"
"ExponentialExpansion"
"EXPEXPAN"
"Expression"
"EXPR"
"ExpressionFunctions2"
"EXPR2"
"ExpressionToUnivariatePowerSeries"
"EXPR2UPS"
"ExpressionSpaceODESolver"
"EXPRODE"
"ExpressionSolve"
"EXPRSOL"
"ExpressionTubePlot"
"EXPRTUBE"
"ExponentialOfUnivariatePuiseuxSeries"
"EXPUPXS"
"ExtendedPolynomialReduction"
"EXTRED"
"FacetCategory"
"FACTCAT"
"FactoredFunctions"
"FACTFUNC"
"FactoringUtilities"
"FACUTIL"
"FakePolynomial"
"FAKEPOL"
"FiniteAbelianMonoidRing"
"FAMR"
"FiniteAbelianMonoidRingFunctions2"
"FAMR2"
"FlexibleArray"
"FARRAY"
"FiniteAlgebraicExtensionField"
"FAXF"
"FiniteBiCPO"
"FBICPO"
"FortranCode"
"FC"
"FiniteCoDcpo"
"FCDCPO"
"FourierComponent"
"FCOMP"
"FortranCodePackage1"
"FCPAK1"
"FortranCodeTools"
"FCTOOL"
"FreeDivisionAlgebra"
"FDALG"
"FiniteDcpo"
"FDCPO"
"FiniteDivisor"
"FDIV"
"FiniteDivisorFunctions2"
"FDIV2"
"FiniteDivisorCategory"
"FDIVCAT"
"FloatElementaryFunctions"
"FELEM"
"FloatEllipticFunctions"
"FELFUN"
"FullyEvalableOver"
"FEVALAB"
"FortranExpression"
"FEXPR"
"FiniteField"
"FF"
"FunctionFieldCategory"
"FFCAT"
"FunctionFieldCategoryFunctions2"
"FFCAT2"
"FiniteFieldCyclicGroup"
"FFCG"
"FiniteFieldCyclicGroupExtensionByPolynomial"
"FFCGP"
"FiniteFieldCyclicGroupExtension"
"FFCGX"
"FiniteFieldFunctions"
"FFF"
"FractionFreeFastGaussian"
"FFFG"
"FractionFreeFastGaussianFractions"
"FFFGF"
"FiniteFieldHomomorphisms"
"FFHOM"
"FiniteFieldCategory"
"FFIELDC"
"FunctionFieldIntegralBasis"
"FFINTBAS"
"FiniteFieldNormalBasis"
"FFNB"
"FiniteFieldNormalBasisExtensionByPolynomial"
"FFNBP"
"FiniteFieldNormalBasisExtension"
"FFNBX"
"FiniteFieldExtensionByPolynomial"
"FFP"
"FiniteFieldPolynomialPackage"
"FFPOLY"
"FiniteFieldPolynomialPackage2"
"FFPOLY2"
"FiniteFieldSolveLinearPolynomialEquation"
"FFSLPE"
"FiniteFieldExtension"
"FFX"
"FGLMIfCanPackage"
"FGLMICPK"
"FreeGroup"
"FGROUP"
"FiniteGraph"
"FGRPH"
"Field"
"FIELD"
"File"
"FILE"
"FileCategory"
"FILECAT"
"FileSerialization"
"FILSER"
"FiniteRankNonAssociativeAlgebra"
"FINAALG"
"FinitelyGenerated"
"FINGEN"
"FiniteGroupPackage"
"FINGPKG"
"FiniteGroup"
"FINGRP"
"Finite"
"FINITE"
"FiniteLattice"
"FINLAT"
"FiniteRankAlgebra"
"FINRALG"
"FiniteLinearAggregate"
"FLAGG"
"FiniteLinearAggregateFunctions2"
"FLAGG2"
"FreeLieAlgebra"
"FLALG"
"FiniteLinearAggregateSort"
"FLASORT"
"FullyLinearlyExplicitOver"
"FLINEXP"
"FloatLiouvilianFunctions"
"FLIOUFUN"
"Float"
"FLOAT"
"FloatingComplexPackage"
"FLOATCP"
"FloatingRealPackage"
"FLOATRP"
"FloatingPointOperations"
"FLOOPS"
"FreeModule"
"FM"
"FreeModuleFunctions2"
"FM2"
"FreeMagma"
"FMAGMA"
"FortranMatrixCategory"
"FMC"
"FreeModuleCategory"
"FMCAT"
"FreeModuleCoefficientFunctions2"
"FMCF2"
"FortranMatrixFunctionCategory"
"FMFUN"
"FiniteMoebiusFunction"
"FMOEBF"
"FreeMonoid"
"FMONOID"
"Format1D"
"FMT1D"
"Format2D"
"FMT2D"
"FortranMachineTypeCategory"
"FMTC"
"FormatterCategory"
"FMTCAT"
"FormatLaTeX"
"FMTLATEX"
"FormatMathJax"
"FMTMJAX"
"FormattedOutput"
"FMTOUT"
"FileName"
"FNAME"
"FileNameCategory"
"FNCAT"
"FunctionGraph"
"FNGRPH"
"FreeNilpotentLie"
"FNLA"
"FortranOutputStackPackage"
"FOP"
"FindOrderFinite"
"FORDER"
"Formatter"
"FORMAT"
"OutputFormatterCategory"
"FORMCAT"
"FortranProgramCategory"
"FORTCAT"
"FortranFunctionCategory"
"FORTFN"
"FortranFormat"
"FORTFORM"
"FortranProgram"
"FORTRAN"
"FloatingPointConvertion"
"FOUT"
"FullPartialFractionExpansion"
"FPARFRAC"
"FullyPatternMatchable"
"FPATMAB"
"FieldOfPrimeCharacteristic"
"FPC"
"FinitePoset"
"FPOSET"
"FloatingPointSystem"
"FPS"
"Factored"
"FR"
"FactoredFunctions2"
"FR2"
"Fraction"
"FRAC"
"FractionFunctions2"
"FRAC2"
"FramedAlgebra"
"FRAMALG"
"FullyRetractableTo"
"FRETRCT"
"FractionalIdeal"
"FRIDEAL"
"FractionalIdealFunctions2"
"FRIDEAL2"
"FractionalIdealAsModule"
"FRIMOD"
"FramedModule"
"FRMOD"
"FramedNonAssociativeAlgebraFunctions2"
"FRNAAF2"
"FramedNonAssociativeAlgebra"
"FRNAALG"
"FactoredFunctionUtilities"
"FRUTIL"
"FunctionSpace"
"FS"
"FunctionSpaceFunctions2"
"FS2"
"FunctionSpaceToExponentialExpansion"
"FS2EXPXP"
"FunctionSpaceToUnivariatePowerSeries"
"FS2UPS"
"FunctionSpaceToUnivariatePowerSeries2"
"FS2UPS2"
"FiniteSetAggregate"
"FSAGG"
"FiniteSetAggregateFunctions2"
"FSAGG2"
"FunctionSpace2"
"FSC2"
"FunctionSpaceComplexIntegration"
"FSCINT"
"FunctionSpaceComplexIntegrationAux"
"FSCINTA"
"FourierSeries"
"FSERIES"
"FloatSpecialFunctions"
"FSFUN"
"FunctionSpaceIntegration"
"FSINT"
"FunctionalSpecialFunction"
"FSPECF"
"FunctionSpacePrimitiveElement"
"FSPRMELT"
"FunctionSpaceReduce"
"FSRED"
"FunctionSpaceRationalRoots"
"FSRROOT"
"FortranScalarType"
"FST"
"FortranType"
"FT"
"FortranTemplate"
"FTEM"
"FunctionCalled"
"FUNCTION"
"FortranVectorCategory"
"FVC"
"FortranVectorFunctionCategory"
"FVFUN"
"GaloisGroupFactorizerSeparate"
"GALFACS"
"GaloisGroupFactorizer"
"GALFACT"
"GaloisGroupFactorizationUtilities"
"GALFACTU"
"GaloisGroupPolynomialUtilities"
"GALPOLYU"
"GaloisGroupUtilities"
"GALUTIL"
"GaussianFactorizationPackage"
"GAUSSFAC"
"GroebnerPackage"
"GB"
"EuclideanGroebnerBasisPackage"
"GBEUCLID"
"GroebnerFactorizationPackage"
"GBF"
"GroebnerInternalPackage"
"GBINTERN"
"GcdBasis"
"GCDBAS"
"GcdDomain"
"GCDDOM"
"GenericNonAssociativeAlgebra"
"GCNAALG"
"GeneralDistributedMultivariatePolynomial"
"GDMP"
"GnuDraw"
"GDRAW"
"GenExEuclid"
"GENEEZ"
"GeneralizedMultivariateFactorize"
"GENMFACT"
"GeneralizedFiniteMoebiusFunction"
"GENMOEBF"
"GeneralPolynomialGcdPackage"
"GENPGCD"
"GenerateUnivariatePowerSeries"
"GENUPS"
"GenerateUnivariatePowerSeries1"
"GENUPS1"
"GenerateUnivariatePowerSeries2"
"GENUPS2"
"GeneralizedUnivariatePowerSeries"
"GENUSER"
"GeneralHenselPackage"
"GHENSEL"
"GeneralModulePolynomial"
"GMODPOL"
"GuessOption"
"GOPT"
"GuessOptionFunctions0"
"GOPT0"
"GosperSummationMethod"
"GOSPER"
"MaybeSkewPolynomialCategory"
"GPOLCAT"
"GeneralPolynomialSet"
"GPOLSET"
"GradedAlgebra"
"GRALG"
"GrayCode"
"GRAY"
"GraphicsDefaults"
"GRDEF"
"GraphImage"
"GRIMAGE"
"GradedModule"
"GRMOD"
"GroebnerSolve"
"GROEBSOL"
"Group"
"GROUP"
"GroupPresentation"
"GROUPP"
"GroupPresentationFunctions1"
"GROUPPF1"
"GeneralUnivariatePowerSeries"
"GSERIES"
"GeneralSparseTable"
"GSTBL"
"GeneralTriangularSet"
"GTSET"
"Guess"
"GUESS"
"GuessAlgebraicNumber"
"GUESSAN"
"GuessExpBin"
"GUESSEB"
"GuessFinite"
"GUESSF"
"GuessFiniteFunctions"
"GUESSF1"
"GuessInteger"
"GUESSINT"
"GuessPolynomial"
"GUESSP"
"GuessPolynomialFunctions"
"GUESSP1"
"GuessPolynomialInteger"
"GUESSPI"
"PiDomain"
"HACKPI"
"HankelPackage"
"HANKP"
"Hashable"
"HASHABL"
"HashState"
"HASHSTAT"
"HashTable"
"HASHTBL"
"HallBasis"
"HB"
"HomogeneousDistributedMultivariatePolynomial"
"HDMP"
"HomogeneousDirectProduct"
"HDP"
"Heap"
"HEAP"
"HyperellipticFiniteDivisor"
"HELLFDIV"
"HeuGcd"
"HEUGCD"
"HexadecimalExpansion"
"HEXADEC"
"HomogeneousAggregate"
"HOAGG"
"Homology"
"HOMOL"
"HopfAlgebra"
"HOPFALG"
"HTMLFormat"
"HTMLFORM"
"HyperbolicFunctionCategory"
"HYPCAT"
"I16Matrix"
"I16MAT"
"I16Vector"
"I16VEC"
"I32Matrix"
"I32MAT"
"I32Vector"
"I32VEC"
"I8Matrix"
"I8MAT"
"I8Vector"
"I8VEC"
"InnerAlgFactor"
"IALGFACT"
"IndexedOneDimensionalArray"
"IARRAY1"
"IndexedTwoDimensionalArray"
"IARRAY2"
"ChineseRemainderToolsForIntegralBases"
"IBACHIN"
"IntegralBasisTools"
"IBATOOL"
"IndexedBits"
"IBITS"
"IntegralBasisPolynomialTools"
"IBPTOOLS"
"IndexCard"
"ICARD"
"InnerCommonDenominator"
"ICDEN"
"PolynomialIdeal"
"IDEAL"
"IdealDecompositionPackage"
"IDECOMP"
"IndexedDirectProductCategory"
"IDPC"
"IndexedDirectProductObject"
"IDPO"
"InnerEigenPackage"
"IEP"
"InnerEvalable"
"IEVALAB"
"IndexedFlexibleArray"
"IFARRAY"
"InnerFiniteField"
"IFF"
"InnerIndexedTwoDimensionalArray"
"IIARRAY2"
"IndexedJetBundle"
"IJB"
"IndexedList"
"ILIST"
"ILogic"
"ILOGIC"
"InnerMatrixLinearAlgebraFunctions"
"IMATLIN"
"InnerMatrixQuotientFieldFunctions"
"IMATQF"
"IndexedMatrix"
"IMATRIX"
"InnerModularHermitePade"
"IMODHP"
"InnerNormalBasisFieldFunctions"
"INBFF"
"IncidenceAlgebra"
"INCALG"
"IncrementingMaps"
"INCRMAPS"
"IndexedExponents"
"INDE"
"InnerNumericEigenPackage"
"INEP"
"InfiniteCyclicGroup"
"INFCG"
"Infinity"
"INFINITY"
"InputForm"
"INFORM"
"InputFormFunctions1"
"INFORM1"
"InfiniteLambertProduct"
"INFPROD0"
"InnerNumericFloatSolvePackage"
"INFSP"
"InnerModularGcd"
"INMODGCD"
"InnerMultFact"
"INNMFACT"
"InnerPolySign"
"INPSIGN"
"IntegerNumberSystem"
"INS"
"Integer"
"INT"
"InnerTable"
"INTABL"
"AlgebraicIntegration"
"INTAF"
"AlgebraicIntegrate"
"INTALG"
"AlgebraicIntegrate2"
"INTALG2"
"IntegerBits"
"INTBIT"
"IntervalCategory"
"INTCAT"
"DenominatorIntegration"
"INTDEN"
"IntegralDomain"
"INTDOM"
"IntegrateSolutions"
"INTDSOL"
"ElementaryIntegration"
"INTEF"
"IntegerFactorizationPackage"
"INTFACT"
"GenusZeroIntegration"
"INTG0"
"GenerateEllipticIntegrals"
"INTGEL"
"IntegerNumberTheoryFunctions"
"INTHEORY"
"AlgebraicHermiteIntegration"
"INTHERAL"
"TranscendentalHermiteIntegration"
"INTHERTR"
"IntegerLocalizedAtPrime"
"INTLOCP"
"PureAlgebraicIntegration"
"INTPAF"
"ParametricTranscendentalIntegration"
"INTPAR1"
"ParametricIntegration"
"INTPAR2"
"PatternMatchIntegration"
"INTPM"
"RationalIntegration"
"INTRAT"
"IntegerRetractions"
"INTRET"
"RationalFunctionIntegration"
"INTRF"
"Interval"
"INTRVL"
"IntegerSolveLinearPolynomialEquation"
"INTSLPE"
"IntegrationTools"
"INTTOOLS"
"TranscendentalIntegration"
"INTTR"
"InverseLaplaceTransform"
"INVLAPLA"
"InnerPAdicInteger"
"IPADIC"
"IndexedProductCategory"
"IPC"
"InnerPrimeField"
"IPF"
"InternalPrintPackage"
"IPRNTPK"
"IntegrationResult"
"IR"
"IntegrationResultFunctions2"
"IR2"
"IntegrationResultToFunction"
"IR2F"
"IntegerRoots"
"IROOT"
"IntegrationResultRFToFunction"
"IRRF2F"
"IrrRepSymNatPackage"
"IRSN"
"InternalRationalUnivariateRepresentationPackage"
"IRURPK"
"IntegerSmithNormalForm"
"ISMITH"
"IndexedString"
"ISTRING"
"InnerPolySum"
"ISUMP"
"InnerSparseUnivariatePowerSeries"
"ISUPS"
"InnerTaylorSeries"
"ITAYLOR"
"InfiniteTupleFunctions2"
"ITFUN2"
"InfiniteTupleFunctions3"
"ITFUN3"
"InnerTrigonometricManipulations"
"ITRIGMNP"
"InfiniteTuple"
"ITUPLE"
"IndexedVector"
"IVECTOR"
"IndexedAggregate"
"IXAGG"
"JetBundleBaseFunctionCategory"
"JBBFC"
"JetBundleCategory"
"JBC"
"JetBundleExpression"
"JBE"
"JetBundleFunctionCategory"
"JBFC"
"JetBundleLinearFunction"
"JBLF"
"JetBundlePolynomial"
"JBP"
"JetBundleSymAna"
"JBSA"
"JetBundle"
"JBUNDLE"
"JetBundleXExpression"
"JBX"
"JetCoordinateTransformation"
"JCT"
"JetDifferentialEquation"
"JDE"
"JetDifferential"
"JDIFF"
"JFriCASSupport"
"JFRICAS"
"JetGroebner"
"JGB"
"JetLazyFunction"
"JLF"
"JoinSemilattice"
"JOINLAT"
"AssociatedJordanAlgebra"
"JORDAN"
"JetVectorField"
"JVF"
"KeyedAccessFile"
"KAFILE"
"KeyedDictionary"
"KDAGG"
"KernelCategory"
"KERCAT"
"Kernel"
"KERNEL"
"KernelFunctions2"
"KERNEL2"
"CoercibleTo"
"KOERCE"
"CoercibleFrom"
"KOERCEF"
"ConvertibleFrom"
"KONVERF"
"ConvertibleTo"
"KONVERT"
"Kovacic"
"KOVACIC"
"LocalAlgebra"
"LA"
"LeftAlgebra"
"LALG"
"Lambda"
"LAMBDA"
"LaplaceTransform"
"LAPLACE"
"Lattice"
"LAT"
"LatticeJoinOfMeets"
"LATJOFM"
"LatticeMeetOfJoins"
"LATMOFJ"
"LaurentPolynomial"
"LAUPOL"
"LazardSetSolvingPackage"
"LAZM3PK"
"LeadingCoefDetermination"
"LEADCDET"
"LieExponentials"
"LEXP"
"LexTriangularPackage"
"LEXTRIPK"
"LiouvillianFunction"
"LF"
"LiouvillianFunctionCategory"
"LFCAT"
"LinGroebnerPackage"
"LGROBP"
"Library"
"LIB"
"AssociatedLieAlgebra"
"LIE"
"LieAlgebra"
"LIECAT"
"PowerSeriesLimitPackage"
"LIMITPS"
"RationalFunctionLimitPackage"
"LIMITRF"
"LinearCombinationUtilities"
"LINCOMB"
"LinearDependence"
"LINDEP"
"LinearlyExplicitOver"
"LINEXP"
"LinearMultivariateMatrixPencil"
"LINPEN"
"List"
"LIST"
"ListFunctions2"
"LIST2"
"ListToMap"
"LIST2MAP"
"ListFunctions3"
"LIST3"
"ListPackage"
"LISTPKG"
"LiftLinearDependence"
"LLINDEP"
"LLLReduction"
"LLLRED"
"ListMultiDictionary"
"LMDICT"
"LeftModule"
"LMODULE"
"ListMonoidOps"
"LMOPS"
"LinearAggregate"
"LNAGG"
"Localize"
"LO"
"ElementaryFunctionLODESolver"
"LODEEF"
"LinearOrdinaryDifferentialOperator"
"LODO"
"LinearOrdinaryDifferentialOperator1"
"LODO1"
"LinearOrdinaryDifferentialOperator2"
"LODO2"
"LinearOrdinaryDifferentialOperator3"
"LODO3"
"LinearOrdinaryDifferentialOperator3Aux"
"LODO3AUX"
"LinearOrdinaryDifferentialOperatorCategory"
"LODOCAT"
"LODOConvertions"
"LODOCONV"
"LinearOrdinaryDifferentialOperatorFactorizer"
"LODOF"
"LinearOrdinaryDifferentialOperatorFactorizer2"
"LODOF2"
"LinearOrdinaryDifferentialOperatorsOps"
"LODOOPS"
"Logic"
"LOGIC"
"Loop"
"LOOP"
"LeftOreRing"
"LORER"
"LinearPolynomialEquationByFractions"
"LPEFRAC"
"LiePolynomial"
"LPOLY"
"ListAggregate"
"LSAGG"
"LinearSystemMatrixPackage"
"LSMP"
"LinearSystemMatrixPackage1"
"LSMP1"
"LinearSystemMatrixPackage2"
"LSMP2"
"LinearSystemPolynomialPackage"
"LSPP"
"LieSquareMatrix"
"LSQM"
"LUDecomposition"
"LUD"
"LyndonWord"
"LWORD"
"LazyStreamAggregate"
"LZSTAGG"
"ThreeDimensionalMatrix"
"M3D"
"ModularAlgebraicGcd"
"MAGCD"
"ModularAlgebraicGcd2"
"MAGCD2"
"ModularAlgebraicGcdOperations"
"MAGCDOC"
"ModularAlgebraicGcdTools2"
"MAGCDT2"
"ModularAlgebraicGcdTools3"
"MAGCDT3"
"ModularAlgebraicGcdTools4"
"MAGCDT4"
"Magma"
"MAGMA"
"MagmaWithUnit"
"MAGMAWU"
"MatrixManipulation"
"MAMA"
"MappingPackageInternalHacks1"
"MAPHACK1"
"MappingPackageInternalHacks2"
"MAPHACK2"
"MappingPackageInternalHacks3"
"MAPHACK3"
"MappingPackage1"
"MAPPKG1"
"MappingPackage2"
"MAPPKG2"
"MappingPackage3"
"MAPPKG3"
"MatrixCategory"
"MATCAT"
"MatrixCategoryFunctions2"
"MATCAT2"
"MathematicalSymbols"
"MATHSYM"
"MatrixLinearAlgebraFunctions"
"MATLIN"
"ModularU32MatrixOperations"
"MATOP32"
"MatrixOperationsCategory"
"MATOPC"
"Matrix"
"MATRIX"
"StorageEfficientMatrixOperations"
"MATSTOR"
"MultiVariableCalculusFunctions"
"MCALCFN"
"MatrixCommonDenominator"
"MCDEN"
"MachineComplex"
"MCMPLX"
"MultiDictionary"
"MDAGG"
"MeetSemilattice"
"MEETLAT"
"MeshCreationRoutinesForThreeDimensions"
"MESH"
"ModularEvaluation1"
"MEVAL1"
"ModularEvaluation2"
"MEVAL2"
"ModularEvaluationCategory"
"MEVCAT"
"MultifunctionGraph"
"MFGRPH"
"MultFiniteFactorize"
"MFINFACT"
"MachineFloat"
"MFLOAT"
"ModularFactorizationOperations"
"MFOPC"
"ModularHermitianRowReduction"
"MHROWRED"
"MachineInteger"
"MINT"
"MakeBinaryCompiledFunction"
"MKBCFUNC"
"MakeCachableSet"
"MKCHSET"
"MakeFloatCompiledFunction"
"MKFLCFN"
"MakeFunction"
"MKFUNC"
"MakeRecord"
"MKRECORD"
"MakeUnaryCompiledFunction"
"MKUCFUNC"
"MultivariateLifting"
"MLIFT"
"MultipleMap"
"MMAP"
"MathMLFormat"
"MMLFORM"
"ModularFactorizationK"
"MODFACK"
"ModularFactorization"
"MODFACT"
"ModularFactorizationGeneral"
"MODFACTG"
"ModularField"
"MODFIELD"
"ModularFactorizationTools1"
"MODFT1"
"ModularFactorizationTools3"
"MODFT3"
"ModularHermitePade"
"MODHP"
"ModularHermitePadeSolver"
"MODHPS"
"ModMonic"
"MODMON"
"ModuleMonomial"
"MODMONOM"
"ModuleOperator"
"MODOP"
"ModularRing"
"MODRING"
"Module"
"MODULE"
"MoebiusTransform"
"MOEBIUS"
"MomentPackage"
"MOMPKG"
"MonogenicAlgebra"
"MONOGEN"
"Monoid"
"MONOID"
"MonomialExtensionTools"
"MONOTOOL"
"MultivariateSkewPolynomialCategory"
"MORECAT"
"MPolyCatFunctions2"
"MPC2"
"MPolyCatFunctions3"
"MPC3"
"MPolyCatPolyFactorizer"
"MPCPF"
"MultivariatePolynomial"
"MPOLY"
"MPolyCatRationalFunctionFactorizer"
"MPRFF"
"MRationalFactorize"
"MRATFAC"
"MonoidRingCategory"
"MRCAT"
"MonoidRingFunctions2"
"MRF2"
"MonoidRing"
"MRING"
"MrvLimitPackage"
"MRVLIM"
"Multiset"
"MSET"
"MultisetAggregate"
"MSETAGG"
"MoreSystemCommands"
"MSYSCMD"
"MergeThing"
"MTHING"
"MultivariateTaylorSeriesCategory"
"MTSCAT"
"MultiplicativeDependence"
"MULDEP"
"MultivariateFactorize"
"MULTFACT"
"MultivariateSquareFree"
"MULTSQFR"
"NonAssociativeAlgebra"
"NAALG"
"NonAssociativeRing"
"NARING"
"NonAssociativeRng"
"NARNG"
"NonAssociativeSemiRing"
"NASRING"
"NonAssociativeSemiRng"
"NASRNG"
"NaiveBeckermannLabahnModular"
"NBLM"
"NumericComplexEigenPackage"
"NCEP"
"NumericContinuedFraction"
"NCNTFRAC"
"NewtonInterpolation"
"NEWTON"
"NumberFieldIntegralBasis"
"NFINTBAS"
"NGroebnerPackage"
"NGROEB"
"NonLinearSolvePackage"
"NLINSOL"
"NonNegativeInteger"
"NNI"
"NonNegativeRational"
"NNRAT"
"NonLinearFirstOrderODESolver"
"NODE1"
"None"
"NONE"
"NoneFunctions1"
"NONE1"
"NormInMonogenicAlgebra"
"NORMMA"
"NormalizationPackage"
"NORMPK"
"NormRetractPackage"
"NORMRETR"
"NPCoef"
"NPCOEF"
"NumericRealEigenPackage"
"NREP"
"NewSparseMultivariatePolynomial"
"NSMP"
"NewSparseUnivariatePolynomial"
"NSUP"
"NewSparseUnivariatePolynomialFunctions2"
"NSUP2"
"NumberTheoreticPolynomialFunctions"
"NTPOLFN"
"NormalizedTriangularSetCategory"
"NTSCAT"
"Numeric"
"NUMERIC"
"NumberFormats"
"NUMFMT"
"NumericalOrdinaryDifferentialEquations"
"NUMODE"
"NumericalQuadrature"
"NUMQUAD"
"NumericTubePlot"
"NUMTUBE"
"OrderedAbelianGroup"
"OAGROUP"
"OrderedAbelianMonoid"
"OAMON"
"OrderedAbelianMonoidSup"
"OAMONS"
"OrderedAbelianSemiGroup"
"OASGP"
"OctonionCategory"
"OC"
"OrderedCancellationAbelianMonoid"
"OCAMON"
"Octonion"
"OCT"
"OctonionCategoryFunctions2"
"OCTCT2"
"ConstantLODE"
"ODECONST"
"ElementaryFunctionODESolver"
"ODEEF"
"ODEIntegration"
"ODEINT"
"PureAlgebraicLODE"
"ODEPAL"
"PrimitiveRatDE"
"ODEPRIM"
"PrimitiveRatRicDE"
"ODEPRRIC"
"RationalLODE"
"ODERAT"
"ReduceLODE"
"ODERED"
"RationalRicDE"
"ODERTRIC"
"SystemODESolver"
"ODESYS"
"ODETools"
"ODETOOLS"
"OrderedDirectProduct"
"ODP"
"OrderlyDifferentialPolynomial"
"ODPOL"
"OrdinaryDifferentialRing"
"ODR"
"OrderlyDifferentialVariable"
"ODVAR"
"OrderedExpression"
"OEXPR"
"OrientedFacet"
"OFACET"
"OutputFormTools"
"OFTOOL"
"OrderedIntegralDomain"
"OINTDOM"
"OpenMath"
"OM"
"OpenMathConnection"
"OMCONN"
"OpenMathDevice"
"OMDEV"
"OpenMathEncoding"
"OMENC"
"OpenMathError"
"OMERR"
"OpenMathErrorKind"
"OMERRK"
"ExpressionToOpenMath"
"OMEXPR"
"OpenMathPackage"
"OMPKG"
"OrderedMultisetAggregate"
"OMSAGG"
"OpenMathServerPackage"
"OMSERVER"
"OnePointCompletion"
"ONECOMP"
"OnePointCompletionFunctions2"
"ONECOMP2"
"Operator"
"OP"
"OperatorHandlers"
"OPHANDL"
"OperationsQuery"
"OPQUERY"
"OrderedCompletion"
"ORDCOMP"
"OrderedCompletionFunctions2"
"ORDCOMP2"
"OrderedFinite"
"ORDFIN"
"OrderingFunctions"
"ORDFUNS"
"OrderedMonoid"
"ORDMON"
"OrderedRing"
"ORDRING"
"OrderedSet"
"ORDSET"
"OrePolynomialMatrixOperations"
"OREMAT"
"UnivariateSkewPolynomialCategory"
"OREPCAT"
"UnivariateSkewPolynomialCategoryOps"
"OREPCTO"
"SparseUnivariateSkewPolynomial"
"ORESUP"
"UnivariateSkewPolynomial"
"OREUP"
"OrthogonalPolynomialFunctions"
"ORTHPOL"
"OrderedSemiGroup"
"OSGROUP"
"OrdSetInts"
"OSI"
"OutputPackage"
"OUT"
"OutputBox"
"OUTBOX"
"OutputForm"
"OUTFORM"
"OrderedVariableList"
"OVAR"
"OrdinaryWeightedPolynomials"
"OWP"
"PadeApproximants"
"PADE"
"PadeContinuousFraction"
"PADECF"
"PadeApproximantPackage"
"PADEPAC"
"PAdicInteger"
"PADIC"
"PAdicIntegerCategory"
"PADICCT"
"PAdicRational"
"PADICRAT"
"PAdicRationalConstructor"
"PADICRC"
"Palette"
"PALETTE"
"PolynomialAN2Expression"
"PAN2EXPR"
"ParametricComplexCurve"
"PARCCURV"
"ParametricPlaneCurveFunctions2"
"PARPC2"
"ParametricPlaneCurve"
"PARPCURV"
"PathArrayPackage"
"PARRPKG"
"ParametricSpaceCurveFunctions2"
"PARSC2"
"ParametricSpaceCurve"
"PARSCURV"
"ParametricSurfaceFunctions2"
"PARSU2"
"ParametricSurface"
"PARSURF"
"PartitionsAndPermutations"
"PARTPERM"
"Patternable"
"PATAB"
"PatternMatchListResult"
"PATLRES"
"PatternMatchable"
"PATMAB"
"PatternMatch"
"PATMATCH"
"PatternMatchResult"
"PATRES"
"PatternMatchResultFunctions2"
"PATRES2"
"Pattern"
"PATTERN"
"PatternFunctions1"
"PATTERN1"
"PatternFunctions2"
"PATTERN2"
"PoincareBirkhoffWittLyndonBasis"
"PBWLB"
"PolynomialCommonDenominator"
"PCDEN"
"PartialDifferentialOperator"
"PDO"
"PartialDifferentialOperatorHelper"
"PDOHLP"
"PartialDifferentialRing"
"PDRING"
"PendantTree"
"PENDTREE"
"Permutation"
"PERM"
"Permanent"
"PERMAN"
"PermutationCategory"
"PERMCAT"
"PermutationGroup"
"PERMGRP"
"PolynomialEvaluationUtilities"
"PEVALUT"
"PrimeField"
"PF"
"ProductFacet"
"PFACET"
"PolynomialFactorizationByRecursion"
"PFBR"
"PolynomialFactorizationExplicit"
"PFECAT"
"PointsOfFiniteOrder"
"PFO"
"PointsOfFiniteOrderRational"
"PFOQ"
"PointsOfFiniteOrderTools"
"PFOTOOLS"
"PartialFraction"
"PFR"
"PartialFractionPackage"
"PFRPAC"
"PartialFractionUtilities"
"PFUTIL"
"PolynomialGcdPackage"
"PGCD"
"PermutationGroupExamples"
"PGE"
"PolyGroebner"
"PGROEB"
"PositiveInteger"
"PI"
"PiCoercions"
"PICOERCE"
"PrincipalIdealDomain"
"PID"
"PolynomialInterpolation"
"PINTERP"
"PolynomialInterpolationAlgorithms"
"PINTERPA"
"ParallelIntegrationTools"
"PIT"
"ParametricLinearEquations"
"PLEQN"
"Plot"
"PLOT"
"PlotFunctions1"
"PLOT1"
"Plot3D"
"PLOT3D"
"PlotTools"
"PLOTTOOL"
"PatternMatchAssertions"
"PMASS"
"FunctionSpaceAssertions"
"PMASSFS"
"PatternMatchPushDown"
"PMDOWN"
"PatternMatchFunctionSpace"
"PMFS"
"PatternMatchIntegerNumberSystem"
"PMINS"
"PatternMatchKernel"
"PMKERNEL"
"PatternMatchListAggregate"
"PMLSAGG"
"PatternMatchPolynomialCategory"
"PMPLCAT"
"AttachPredicates"
"PMPRED"
"FunctionSpaceAttachPredicates"
"PMPREDFS"
"PatternMatchQuotientFieldCategory"
"PMQFCAT"
"PatternMatchSymbol"
"PMSYM"
"PatternMatchTools"
"PMTOOLS"
"PolynomialNumberTheoryFunctions"
"PNTHEORY"
"Point"
"POINT"
"PolToPol"
"POLTOPOL"
"RealPolynomialUtilitiesPackage"
"POLUTIL"
"VectorPolynomialOperationsF"
"POLVECF"
"VectorPolynomialOperationsP"
"POLVECP"
"Polynomial"
"POLY"
"PolynomialFunctions2"
"POLY2"
"PolynomialToUnivariatePolynomial"
"POLY2UP"
"PolynomialCategory"
"POLYCAT"
"PolynomialCategoryQuotientFunctions"
"POLYCATQ"
"PolynomialCategoryLifting"
"POLYLIFT"
"PolynomialRoots"
"POLYROOT"
"U32VectorPolynomialOperations"
"POLYVEC"
"PartialOrder"
"PORDER"
"Poset"
"POSET"
"PosetFactory"
"POSETF"
"PlottablePlaneCurveCategory"
"PPCURVE"
"PolynomialRing"
"PR"
"PrecomputedAssociatedEquations"
"PREASSOC"
"Preorder"
"PREORD"
"PrimGCD"
"PRIGCD3"
"PrimitiveArray"
"PRIMARR"
"PrimitiveArrayFunctions2"
"PRIMARR2"
"PrimitiveFunctionCategory"
"PRIMCAT"
"PrimitiveElement"
"PRIMELT"
"IntegerPrimesPackage"
"PRIMES"
"PrimitiveTwoDimensionalArray"
"PRIMMAT2"
"PrintPackage"
"PRINT"
"Product"
"PRODUCT"
"PriorityQueueAggregate"
"PRQAGG"
"PolynomialRationalRoots"
"PRROOT"
"PseudoRemainderSequence"
"PRS"
"Partition"
"PRTITION"
"PowerSeriesCategory"
"PSCAT"
"PlottableSpaceCurveCategory"
"PSCURVE"
"PolynomialSetCategory"
"PSETCAT"
"PolynomialSetUtilitiesPackage"
"PSETPK"
"PseudoLinearNormalForm"
"PSEUDLIN"
"PolynomialSquareFree"
"PSQFR"
"PointCategory"
"PTCAT"
"PointFunctions2"
"PTFUNC2"
"PointPackage"
"PTPACK"
"PartialTranscendentalFunctions"
"PTRANFN"
"PushVariables"
"PUSHVAR"
"PAdicWildFunctionFieldIntegralBasis"
"PWFFINTB"
"QuasiAlgebraicSet"
"QALGSET"
"QuasiAlgebraicSet2"
"QALGSET2"
"QuasiComponentPackage"
"QCMPACK"
"QueryEquation"
"QEQUAT"
"QuotientFieldCategory"
"QFCAT"
"QuotientFieldCategoryFunctions2"
"QFCAT2"
"QuadraticForm"
"QFORM"
"QueueAggregate"
"QUAGG"
"Quaternion"
"QUAT"
"GeneralQuaternion"
"QUAT2"
"QuaternionCategory"
"QUATCAT"
"QuaternionCategoryFunctions2"
"QUATCT2"
"Queue"
"QUEUE"
"RadicalCategory"
"RADCAT"
"RadicalFunctionField"
"RADFF"
"RadixExpansion"
"RADIX"
"RadixUtilities"
"RADUTIL"
"RandomNumberSource"
"RANDSRC"
"RationalFactorize"
"RATFACT"
"UnivariateSeriesWithRationalExponents"
"RATPSCT"
"RationalRetractions"
"RATRET"
"RecursiveAggregate"
"RCAGG"
"RealClosedField"
"RCFIELD"
"RDEaux"
"RDEAUX"
"ElementaryRischDEX"
"RDEEFX"
"ElementaryRischDEX2"
"RDEEFX2"
"ParametricRischDE"
"RDEPAR"
"RandomDistributions"
"RDIST"
"ReducedDivisor"
"RDIV"
"RealConstant"
"REAL"
"RealZeroPackage"
"REAL0"
"RealZeroPackageQ"
"REAL0Q"
"RealSolvePackage"
"REALSOLV"
"RealClosure"
"RECLOS"
"RecurrenceOperator"
"RECOP"
"ReductionOfOrder"
"REDORDER"
"Reference"
"REF"
"RegularTriangularSet"
"REGSET"
"RadicalEigenPackage"
"REP"
"RepresentationPackage1"
"REP1"
"RepresentationPackage2"
"REP2"
"RepeatedDoubling"
"REPDB"
"RepeatedSquaring"
"REPSQ"
"ResolveLatticeCompletion"
"RESLATC"
"ResidueRing"
"RESRING"
"Result"
"RESULT"
"RetractableFrom"
"RETFROM"
"RetractableTo"
"RETRACT"
"RetractSolvePackage"
"RETSOL"
"RationalFunction"
"RF"
"RandomFloatDistributions"
"RFDIST"
"RationalFunctionFactor"
"RFFACT"
"RootFSSplit"
"RFSSPLIT"
"RegularChain"
"RGCHAIN"
"RandomIntegerDistributions"
"RIDIST"
"Ring"
"RING"
"RationalInterpolation"
"RINTERP"
"RectangularMatrixCategory"
"RMATCAT"
"RectangularMatrix"
"RMATRIX"
"RectangularMatrixCategoryFunctions2"
"RMCAT2"
"RightModule"
"RMODULE"
"Rng"
"RNG"
"RealNormalizationUtilities"
"RNORM"
"RealNumberSystem"
"RNS"
"RightOpenIntervalRootCharacterization"
"ROIRC"
"RomanNumeral"
"ROMAN"
"RootUtilities"
"ROOTUT"
"RecursivePolynomialCategory"
"RPOLCAT"
"RealRootCharacterizationCategory"
"RRCC"
"RegularSetDecompositionPackage"
"RSDCMPK"
"RegularTriangularSetCategory"
"RSETCAT"
"RegularTriangularSetGcdPackage"
"RSETGCD"
"RootSimplification"
"RSIMP"
"RewriteRule"
"RULE"
"RuleCalled"
"RULECOLD"
"Ruleset"
"RULESET"
"RationalUnivariateRepresentationPackage"
"RURPK"
"SimpleAlgebraicExtension"
"SAE"
"SingletonAsOrderedSet"
"SAOS"
"SArgand"
"SARGND"
"SBoundary"
"SBOUND"
"SortedCache"
"SCACHE"
"ScanningUtilities"
"SCANUTIL"
"SimpleCell"
"SCELL"
"Scene"
"SCENE"
"SceneIFS"
"SCIFS"
"SceneNamedPoints"
"SCNP"
"SConformal"
"SCONF"
"StructuralConstantsPackage"
"SCPKG"
"SCartesian"
"SCRT"
"SequentialDifferentialPolynomial"
"SDPOL"
"SequentialDifferentialVariable"
"SDVAR"
"Segment"
"SEG"
"SegmentFunctions2"
"SEG2"
"SegmentBinding"
"SEGBIND"
"SegmentBindingFunctions2"
"SEGBIND2"
"SegmentCategory"
"SEGCAT"
"SegmentExpansionCategory"
"SEGXCAT"
"SparseEchelonMatrix"
"SEM"
"Sequence"
"SEQU"
"SequenceFunctions2"
"SEQU2"
"SequenceCategory"
"SEQUCAT"
"Set"
"SET"
"SetAggregate"
"SETAGG"
"SetCategory"
"SETCAT"
"SubsetLattice"
"SETLAT"
"SetOfMIntegersInOneToN"
"SETMN"
"SExpression"
"SEX"
"SExpressionCategory"
"SEXCAT"
"SExpressionOf"
"SEXOF"
"SimpleFortranProgram"
"SFORT"
"SquareFreeQuasiComponentPackage"
"SFQCMPK"
"SquareFreeRegularTriangularSetGcdPackage"
"SFRGCD"
"SquareFreeRegularTriangularSetCategory"
"SFRTCAT"
"SymmetricGroupCombinatoricFunctions"
"SGCF"
"SemiGroup"
"SGROUP"
"SplitHomogeneousDirectProduct"
"SHDP"
"SturmHabichtPackage"
"SHP"
"ElementaryFunctionSign"
"SIGNEF"
"RationalFunctionSign"
"SIGNRF"
"SimplifyAlgebraicNumberConvertPackage"
"SIMPAN"
"FiniteSimplicialComplex"
"SIMPC"
"SimplicialComplexFactory"
"SIMPCF"
"SingleInteger"
"SINT"
"StackAggregate"
"SKAGG"
"SKICombinators"
"SKICOMB"
"SparseMultivariateSkewPolynomial"
"SKSMP"
"SquareMatrixCategory"
"SMATCAT"
"SmithNormalForm"
"SMITH"
"SparseMultivariatePolynomial"
"SMP"
"SparsePolynomialCoercionHelpers"
"SMPCOER"
"SparseMultivariatePolynomialExpressions"
"SMPEXPR"
"SparseMultivariateTaylorSeries"
"SMTS"
"SquareFreeNormalizedTriangularSetCategory"
"SNTSCAT"
"PolynomialSolveByFormulas"
"SOLVEFOR"
"RadicalSolvePackage"
"SOLVERAD"
"TransSolvePackageService"
"SOLVESER"
"TransSolvePackage"
"SOLVETRA"
"SmallOrdinal"
"SORD"
"SortedExponentVector"
"SOREXPV"
"SortPackage"
"SORTPAK"
"ThreeSpace"
"SPACE3"
"ThreeSpaceCategory"
"SPACEC"
"SpecialOutputPackage"
"SPECOUT"
"SpecialFunctionCategory"
"SPFCAT"
"SpecialFunctionUnivariateTaylorSeries"
"SPFUTS"
"SplittingNode"
"SPLNODE"
"SplittingTree"
"SPLTREE"
"SPointCategory"
"SPTCAT"
"SquareMatrix"
"SQMATRIX"
"StringAggregate"
"SRAGG"
"SquareFreeRegularSetDecompositionPackage"
"SRDCMPK"
"SquareFreeRegularTriangularSet"
"SREGSET"
"SemiRing"
"SRING"
"SemiRng"
"SRNG"
"SolvableSkewPolynomialCategory"
"SSKPOLC"
"Stack"
"STACK"
"StreamAggregate"
"STAGG"
"SparseTable"
"STBL"
"StepThrough"
"STEP"
"StreamExponentialSeriesOperations"
"STEXPS"
"StreamExponentialSeriesTranscendentalFunctions"
"STEXPST"
"StreamTensor"
"STNSR"
"STransform"
"STR"
"STransformPackage"
"STRANS"
"Stream"
"STREAM"
"StreamFunctions1"
"STREAM1"
"StreamFunctions2"
"STREAM2"
"StreamFunctions3"
"STREAM3"
"StringCategory"
"STRICAT"
"String"
"STRING"
"StringTable"
"STRTBL"
"StreamTaylorSeriesOperations2"
"STTAYLO2"
"StreamTaylorSeriesOperations"
"STTAYLOR"
"StreamTaylorSeriesOperationsCategory"
"STTAYOC"
"StreamTranscendentalFunctions"
"STTF"
"StreamTranscendentalFunctionsNonCommutative"
"STTFNC"
"SubResultantPackage"
"SUBRESP"
"SubSpace"
"SUBSPACE"
"SuchThat"
"SUCH"
"SparseUnivariateLaurentSeries"
"SULS"
"FunctionSpaceSum"
"SUMFS"
"RationalFunctionSum"
"SUMRF"
"SparseUnivariatePolynomial"
"SUP"
"SparseUnivariatePolynomialFunctions2"
"SUP2"
"SparseUnivariatePuiseuxSeries"
"SUPXS"
"SparseUnivariateTaylorSeries"
"SUTS"
"Switch"
"SWITCH"
"SymmetryAnalysis"
"SYMANA"
"Symbol"
"SYMBOL"
"SymmetricFunctions"
"SYMFUNC"
"SymmetricPolynomial"
"SYMPOLY"
"TheSymbolTable"
"SYMS"
"SymbolTable"
"SYMTAB"
"SystemSolvePackage"
"SYSSOLP"
"TableauxBumpers"
"TABLBUMP"
"Table"
"TABLE"
"Tableau"
"TABLEAU"
"TangentExpansions"
"TANEXP"
"TableAggregate"
"TBAGG"
"TabulatedComputationPackage"
"TBCMPPK"
"TemplateUtilities"
"TEMUTL"
"TensorProductCategory"
"TENSCAT"
"TensorProduct"
"TENSOR"
"TensorPowerCategory"
"TENSPC"
"TensorPowerFunctions2"
"TENSPO2"
"TensorPower"
"TENSPOW"
"TensorProductProperty"
"TENSPRP"
"UnittestAux"
"TESTAUX"
"UnittestCount"
"TESTCNT"
"Unittest"
"TESTUNIT"
"TexFormat"
"TEX"
"TexFormat1"
"TEX1"
"TexParser"
"TEXPARSE"
"TeXScanner"
"TEXSCAN"
"TextFile"
"TEXTFILE"
"TeXTree"
"TEXTREE"
"TimeoutPackage"
"TIMEOUT"
"TexmacsFormat"
"TMFORM"
"ToolsForSign"
"TOOLSIGN"
"TopLevelThreeSpace"
"TOPSP"
"TranscendentalFunctionCategory"
"TRANFUN"
"Tree"
"TREE"
"TrigonometricFunctionCategory"
"TRIGCAT"
"TrigonometricManipulations"
"TRIGMNIP"
"TrigonometricManipulationsAux"
"TRIGMNPA"
"TriangularMatrixOperations"
"TRIMAT"
"TranscendentalManipulations"
"TRMANIP"
"TaylorSeries"
"TS"
"TaylorSeriesExpansion"
"TSEREXP"
"TaylorSeriesExpansionGeneralized"
"TSEREXPG"
"TaylorSeriesExpansionLaurent"
"TSEREXPL"
"TaylorSeriesExpansionPuiseux"
"TSEREXPP"
"TaylorSeriesExpansionTaylor"
"TSEREXPT"
"TriangularSetCategory"
"TSETCAT"
"TubePlot"
"TUBE"
"TubePlotTools"
"TUBETOOL"
"Tuple"
"TUPLE"
"TwoFactorize"
"TWOFACT"
"Type"
"TYPE"
"Typed"
"TYPED"
"U16Matrix"
"U16MAT"
"U16Vector"
"U16VEC"
"U32Matrix"
"U32MAT"
"U32Vector"
"U32VEC"
"U64Int"
"U64INT"
"U8Matrix"
"U8MAT"
"U8Vector"
"U8VEC"
"UndirectedGraph"
"UDGRPH"
"UserDefinedPartialOrdering"
"UDPO"
"UserDefinedVariableOrdering"
"UDVO"
"UniqueFactorizationDomain"
"UFD"
"UnivariateFiniteFieldFactorize"
"UFFACT"
"UnivariateFormalPowerSeries"
"UFPS"
"UnivariateFormalPowerSeriesFunctions"
"UFPS1"
"UnitGaussianElimination"
"UGAUSS"
"UnivariateLaurentSeries"
"ULS"
"UnivariateLaurentSeriesFunctions2"
"ULS2"
"UnivariateLaurentSeriesCategory"
"ULSCAT"
"UnivariateLaurentSeriesConstructorCategory"
"ULSCCAT"
"UnivariateLaurentSeriesConstructor"
"ULSCONS"
"UniversalSegment"
"UNISEG"
"UniversalSegmentFunctions2"
"UNISEG2"
"Untyped"
"UNTYPED"
"UnivariatePolynomial"
"UP"
"UnivariatePolynomialFunctions2"
"UP2"
"UnivariatePolynomialCommonDenominator"
"UPCDEN"
"UnivariatePolynomialDecompositionPackage"
"UPDECOMP"
"UnivariatePolynomialDivisionPackage"
"UPDIVP"
"UnivariatePolynomialMultiplicationPackage"
"UPMP"
"UnivariatePolynomialCategory"
"UPOLYC"
"UnivariatePolynomialCategoryFunctions2"
"UPOLYC2"
"UnivariatePowerSeriesCategory"
"UPSCAT"
"UnivariatePolynomialSquareFree"
"UPSQFREE"
"UnivariatePuiseuxSeries"
"UPXS"
"UnivariatePuiseuxSeriesFunctions2"
"UPXS2"
"UnivariatePuiseuxSeriesCategory"
"UPXSCAT"
"UnivariatePuiseuxSeriesConstructorCategory"
"UPXSCCA"
"UnivariatePuiseuxSeriesConstructor"
"UPXSCONS"
"UnivariatePuiseuxSeriesWithExponentialSingularity"
"UPXSSING"
"UnaryRecursiveAggregate"
"URAGG"
"UnivariateTaylorSeries"
"UTS"
"UnivariateTaylorSeriesFunctions2"
"UTS2"
"UnivariateTaylorSeriesCategory"
"UTSCAT"
"UnivariateTaylorSeriesODESolver"
"UTSODE"
"UTSodetools"
"UTSODETL"
"TaylorSolve"
"UTSSOL"
"VarCat"
"VARCAT"
"Variable"
"VARIABLE"
"VectorModularReconstructor"
"VECREC1"
"VectorIntegerReconstructor"
"VECREC2"
"VectorCategory"
"VECTCAT"
"Vector"
"VECTOR"
"VectorFunctions2"
"VECTOR2"
"VectorHermitePadeSolver"
"VHPSOLV"
"ViewportPackage"
"VIEW"
"TwoDimensionalViewport"
"VIEW2D"
"ThreeDimensionalViewport"
"VIEW3D"
"ViewDefaultsPackage"
"VIEWDEF"
"Void"
"VOID"
"VectorSpaceBasis"
"VSBASIS"
"WeierstrassPreparation"
"WEIER"
"WildFunctionFieldIntegralBasis"
"WFFINTBS"
"WeightedGraph"
"WGRPH"
"WeightedPolynomials"
"WP"
"WuWenTsunTriangularSet"
"WUTSET"
"XAlgebra"
"XALG"
"XDistributedPolynomial"
"XDPOLY"
"XDistributedPolynomialFunctions"
"XDPOLYF"
"XExponentialPackage"
"XEXPPKG"
"ExtensionField"
"XF"
"XFreeAlgebra"
"XFALG"
"XHashTable"
"XHASHTBL"
"ExportXml"
"XML"
"XmlAttribute"
"XMLAT"
"XmlElement"
"XMLEL"
"XPBWPolynomial"
"XPBWPOLY"
"XPolynomialFactor"
"XPFACT"
"XPolynomial"
"XPOLY"
"XPolynomialsCat"
"XPOLYC"
"XPolynomialRing"
"XPR"
"XRecursivePolynomial"
"XRPOLY"
"ParadoxicalCombinatorsForStreams"
"YSTREAM"
"ZeroDimensionalSolvePackage"
"ZDSOLVE"
"IntegerLinearDependence"
"ZLINDEP"
"IntegerMod"
"ZMOD"
"Enumeration"
"Mapping"
"Union"
"Record"
"Category"
))
         (a (make-vector (length l) 0)))
    (dolist (name l a) (intern name a))))

(provide 'fricas-cpl)
